@@ -19,20 +19,21 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *     add prefix
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *     add prefix
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <string.h>
 #include <glib.h>
 #include "tlf.h"
+#include "bands.h"
 
 #define MAX_PFX_LEN 5
 
-int nr_of_px = 0;
-int nr_of_px_ab = 0;
+unsigned int nr_of_px = 0;
+unsigned int nr_of_px_ab = 0;
 
 
 struct {
@@ -40,12 +41,10 @@ struct {
     int bands;
 } prefixes_worked[MAX_CALLS];
 
-int pfxs_per_band[NBANDS] = {0, 0, 0, 0, 0, 0, 0, 0, 0};
+unsigned int pfxs_per_band[NBANDS] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
-int add_pfx(char *pxstr)
-{
+int add_pfx(char *pxstr, unsigned int bandindex) {
     extern int pfxmultab;
-    extern int bandinx;
     int q = 0, found = 0, bandfound = 0;
 
     prefixes_worked[nr_of_px].pfx[0] = '\0';
@@ -56,14 +55,13 @@ int add_pfx(char *pxstr)
 	if (strcmp(pxstr, prefixes_worked[q].pfx) == 0) {
 	    /* pfx already worked */
 	    found = 1;
-	    if (prefixes_worked[q].bands & inxes[bandinx]) {
+	    if (prefixes_worked[q].bands & inxes[bandindex]) {
 		bandfound = 1;
-	    }
-	    else {
+	    } else {
 		/* pfx new on band */
-		prefixes_worked[q].bands |= inxes[bandinx];
+		prefixes_worked[q].bands |= inxes[bandindex];
 		nr_of_px_ab++;
-		pfxs_per_band[bandinx]++;
+		pfxs_per_band[bandindex]++;
 	    }
 	    break;
 	}
@@ -71,33 +69,32 @@ int add_pfx(char *pxstr)
 
     if (found != 1) {
 	/* new pfx */
-	g_strlcpy(prefixes_worked[nr_of_px].pfx, pxstr, MAX_PFX_LEN+1);
-	prefixes_worked[nr_of_px].bands |= inxes[bandinx];
+	g_strlcpy(prefixes_worked[nr_of_px].pfx, pxstr, MAX_PFX_LEN + 1);
+	prefixes_worked[nr_of_px].bands |= inxes[bandindex];
 	nr_of_px++;
 	nr_of_px_ab++;
-	pfxs_per_band[bandinx]++;
+	pfxs_per_band[bandindex]++;
     }
 
     if (pfxmultab != 1) {
 	return (found);
-    }
-    else {
+    } else {
 	return (bandfound);
     }
 }
 
 
-int GetNrOfPfx_once() {
+unsigned int GetNrOfPfx_once() {
     return nr_of_px;
 }
 
 
-int GetNrOfPfx_multiband() {
+unsigned int GetNrOfPfx_multiband() {
     return nr_of_px_ab;
 }
 
 
-int GetNrOfPfx_OnBand(int bandindex) {
+unsigned int GetNrOfPfx_OnBand(unsigned int bandindex) {
     if (bandindex < NBANDS)
 	return pfxs_per_band[bandindex];
     else
@@ -111,8 +108,8 @@ void InitPfx() {
     nr_of_px = 0;
     nr_of_px_ab = 0;
 
-    for(i = 0; i < NBANDS; i++) {
-        pfxs_per_band[i] = 0;
+    for (i = 0; i < NBANDS; i++) {
+	pfxs_per_band[i] = 0;
     }
 }
 
