@@ -24,6 +24,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "err_utils.h"
 #include "fldigixmlrpc.h"
 #include "getctydata.h"
 #include "get_time.h"
@@ -54,7 +55,7 @@ extern int recv_error;
 extern char thisnode;
 extern int lanspotflg;
 extern char talkarray[5][62];
-extern float node_frequencies[MAXNODES];
+extern freq_t node_frequencies[MAXNODES];
 extern int qsonum;
 extern char qsonrstr[5];
 extern int lanqsos;
@@ -76,29 +77,28 @@ static pthread_cond_t backgrnd_process_stopped_cond = PTHREAD_COND_INITIALIZER;
 int cw_simulator(void);
 
 void stop_background_process(void) {
-	pthread_mutex_lock(&stop_backgrnd_process_mutex);
-	assert(stop_backgrnd_process == 0);
-	stop_backgrnd_process = 1;
-	pthread_cond_wait(&backgrnd_process_stopped_cond, &stop_backgrnd_process_mutex);
-	pthread_mutex_unlock(&stop_backgrnd_process_mutex);
+    pthread_mutex_lock(&stop_backgrnd_process_mutex);
+    assert(stop_backgrnd_process == 0);
+    stop_backgrnd_process = 1;
+    pthread_cond_wait(&backgrnd_process_stopped_cond, &stop_backgrnd_process_mutex);
+    pthread_mutex_unlock(&stop_backgrnd_process_mutex);
 }
 
 void start_background_process(void) {
-	pthread_mutex_lock(&stop_backgrnd_process_mutex);
-	assert(stop_backgrnd_process == 1);
-	stop_backgrnd_process = 0;
-	pthread_cond_broadcast(&start_backgrnd_process_cond);
-	pthread_mutex_unlock(&stop_backgrnd_process_mutex);
+    pthread_mutex_lock(&stop_backgrnd_process_mutex);
+    assert(stop_backgrnd_process == 1);
+    stop_backgrnd_process = 0;
+    pthread_cond_broadcast(&start_backgrnd_process_cond);
+    pthread_mutex_unlock(&stop_backgrnd_process_mutex);
 }
 
-static void background_process_wait(void)
-{
-	pthread_mutex_lock(&stop_backgrnd_process_mutex);
-	if (stop_backgrnd_process) {
-		pthread_cond_broadcast(&backgrnd_process_stopped_cond);
-		pthread_cond_wait(&start_backgrnd_process_cond, &stop_backgrnd_process_mutex);
-	}
-	pthread_mutex_unlock(&stop_backgrnd_process_mutex);
+static void background_process_wait(void) {
+    pthread_mutex_lock(&stop_backgrnd_process_mutex);
+    if (stop_backgrnd_process) {
+	pthread_cond_broadcast(&backgrnd_process_stopped_cond);
+	pthread_cond_wait(&start_backgrnd_process_cond, &stop_backgrnd_process_mutex);
+    }
+    pthread_mutex_unlock(&stop_backgrnd_process_mutex);
 }
 
 void *background_process(void *ptr) {
@@ -106,7 +106,7 @@ void *background_process(void *ptr) {
     extern int landebug;
     extern struct tm *time_ptr;
 
-    static int i, t;
+    static int i;
     static char prmessage[256];
     static int lantimesync = 0;
     static int fldigi_rpc_cnt = 0;
@@ -190,10 +190,7 @@ void *background_process(void *ptr) {
 		}
 	    }
 	    if ((*lan_message != '\0') && (lan_message[0] == thisnode)) {
-		mvprintw(24, 0,
-			 "Warning: NODE ID CONFLICT ?! You should use another ID! ");
-		refreshp();
-		sleep(5);
+		TLF_LOG_WARN("%s", "Warning: NODE ID CONFLICT ?! You should use another ID! ");
 	    }
 
 	    if ((*lan_message != '\0')
@@ -225,10 +222,7 @@ void *background_process(void *ptr) {
 		    case CLUSTERMSG:
 			strncpy(prmessage, lan_message + 2, 80);
 			if (strstr(prmessage, call) != NULL) {	// alert for cluster messages
-			    mvprintw(24, 0,
-				     "                                                                           ");
-			    mvprintw(24, 0, "%s", prmessage);
-			    refreshp();
+			    TLF_LOG_INFO(prmessage);
 			}
 
 			addtext(prmessage);
@@ -240,23 +234,20 @@ void *background_process(void *ptr) {
 			lanspotflg = 0;
 			break;
 		    case TLFMSG:
-			for (t = 0; t < 4; t++)
+			for (int t = 0; t < 4; t++)
 			    strcpy(talkarray[t], talkarray[t + 1]);
 
 			talkarray[4][0] = lan_message[0];
 			talkarray[4][1] = ':';
 			talkarray[4][2] = '\0';
 			strncat(talkarray[4], lan_message + 2, 60);
-			mvprintw(24, 0,
-				 "                                                                           ");
-			mvprintw(24, 0, " MSG from %s", talkarray[4]);
-			refreshp();
+			TLF_LOG_INFO(" MSG from %s", talkarray[4]);
 			break;
 		    case FREQMSG:
 			if ((lan_message[0] >= 'A')
 				&& (lan_message[0] <= 'A' + MAXNODES)) {
 			    node_frequencies[lan_message[0] - 'A'] =
-				atof(lan_message + 2);
+				atof(lan_message + 2) * 1000.0;
 			    break;
 			}
 		    case INCQSONUM:
@@ -305,6 +296,25 @@ void *background_process(void *ptr) {
     return (NULL);
 }
 
+/* CW Simulator
+ * works only for RUN mode in CQWW */
+
+static void twoSpaces() {
+    sendmessage("  ");
+    write_keyer();
+}
+
+void setSimulatorState(int n) {
+    extern int simulator;
+    extern int simulator_mode;
+
+    if (trxmode == CWMODE || trxmode == DIGIMODE) {
+	if (simulator != 0)
+	    simulator_mode = n;
+    }
+}
+
+
 int cw_simulator(void) {
 
     extern int simulator;
@@ -320,7 +330,7 @@ int cw_simulator(void) {
     char callcpy[80];
 
     if (simulator == 0)
-	return (-1);
+	return -1;
 
     if (simulator_mode == 1) {
 
@@ -330,44 +340,44 @@ int cw_simulator(void) {
 
 	strcpy(tonecpy, tonestr);
 
-	switch (this_second) {
-	    case 48:
+	switch (this_second % 10) {
+	    case 0:
 		strcpy(simulator_tone, "625");
 		break;
 
-	    case 49:
+	    case 1:
 		strcpy(simulator_tone, "800");
 		break;
 
-	    case 50:
+	    case 2:
 		strcpy(simulator_tone, "650");
 		break;
 
-	    case 51:
+	    case 3:
 		strcpy(simulator_tone, "750");
 		break;
 
-	    case 52:
+	    case 4:
 		strcpy(simulator_tone, "700");
 		break;
 
-	    case 53:
+	    case 5:
 		strcpy(simulator_tone, "725");
 		break;
 
-	    case 54:
+	    case 6:
 		strcpy(simulator_tone, "675");
 		break;
 
-	    case 55:
+	    case 7:
 		strcpy(simulator_tone, "775");
 		break;
 
-	    case 56:
+	    case 8:
 		strcpy(simulator_tone, "600");
 		break;
 
-	    case 57:
+	    case 9:
 		strcpy(simulator_tone, "640");
 		break;
 
@@ -378,9 +388,10 @@ int cw_simulator(void) {
 	}
 
 	strcpy(tonestr, simulator_tone);
-
 	write_tone();
 
+	twoSpaces();
+
 	callnumber =
 	    callnumber + simulator_seed + system_secs -
 	    (60 * (int)(system_secs / 60));
@@ -390,6 +401,7 @@ int cw_simulator(void) {
 
 	sendmessage(CALLMASTERARRAY(callnumber));
 	write_keyer();
+
 	simulator_mode = 0;
 
 	strcpy(tonestr, tonecpy);
@@ -403,16 +415,17 @@ int cw_simulator(void) {
 	strcpy(tonestr, simulator_tone);
 	write_tone();
 
-	strcpy(callcpy, CALLMASTERARRAY(callnumber));
+	twoSpaces();
 
+	strcpy(callcpy, CALLMASTERARRAY(callnumber));
 	getctydata(callcpy);
 
 	str = g_strdup_printf("TU 5NN %2s", zone_export);
 	sendmessage(str);
+	write_keyer();
 	g_free(str);
 
 	simulator_mode = 0;
-	write_keyer();
 
 	strcpy(tonestr, tonecpy);
 	write_tone();
@@ -426,21 +439,23 @@ int cw_simulator(void) {
 	strcpy(tonestr, simulator_tone);
 	write_tone();
 
+	twoSpaces();
+
 	strcpy(callcpy, CALLMASTERARRAY(callnumber));
 	getctydata(callcpy);
 
 	str = g_strdup_printf("DE %s TU 5NN %s",
 			      CALLMASTERARRAY(callnumber), zone_export);
 	sendmessage(str);
+	write_keyer();
 	g_free(str);
 
 	simulator_mode = 0;
-	write_keyer();
 
 	strcpy(tonestr, tonecpy);
 	write_tone();
 
     }
 
-    return (0);
+    return 0;
 }
