@@ -48,6 +48,13 @@
 #define DISTANCE(x, y) \
     ( x < y ? y - x : x -y )
 
+#define TOPLINE 14
+#define LASTLINE (LINES - 2)
+
+#define LINELENGTH 80
+#define COLUMNS ((LINELENGTH - 14) / SPOT_COLUMN_WIDTH)
+#define NR_SPOTS ((LASTLINE - TOPLINE + 1) * COLUMNS)
+
 pthread_mutex_t bm_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /** \brief sorted list of all recent DX spots
@@ -69,7 +76,7 @@ bm_config_t bm_config = {
 };
 short	bm_initialized = 0;
 
-extern float freq;
+extern freq_t freq;
 extern int trx_control;
 extern int bandinx;
 extern int trxmode;
@@ -131,7 +138,6 @@ void bmdata_read_file() {
 
     if ((fp = fopen(".bmdata.dat", "r")) != NULL && bmdata_parsed == 0) {
 	bmdata_parsed = 1;
-	timediff = 0;
 	if (fgets(line, 50, fp)) {
 	    sscanf(line, "%d", &last_bm_save_time);
 	    gettimeofday(&tv, NULL);
@@ -207,7 +213,7 @@ void bm_init() {
  *
  * \return CWMODE, DIGIMODE or SSBMODE
  */
-int freq2mode(int freq, int band) {
+int freq2mode(freq_t freq, int band) {
     if (freq <= cwcorner[band])
 	return CWMODE;
     else if (freq < ssbcorner[band])
@@ -241,7 +247,7 @@ void bm_add(char *s) {
     if (strncmp(line + 6, "TLF-", 4) == 0)
 	node = line[10];		/* get sending node id */
 
-    bandmap_addspot(call, (unsigned int)(atof(line + 16) * 1000), node);
+    bandmap_addspot(call, atof(line + 16) * 1000, node);
     g_free(line);
 }
 
@@ -266,7 +272,7 @@ gint	cmp_freq(spot *a, spot *b) {
  * \param freq 		on which frequency heard
  * \param node		reporting node
  */
-void bandmap_addspot(char *call, unsigned int freq, char node) {
+void bandmap_addspot(char *call, freq_t freq, char node) {
     /* - if a spot on that band and mode is already in list replace old entry
      *   with new one and set timeout to SPOT_NEW,
      *   otherwise add it to the list as new
@@ -488,22 +494,22 @@ void bm_show_info() {
 
     /* show info field on the right */
     attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
-    move(14, 66);
-    vline(ACS_VLINE, 10);
+    move(TOPLINE, 66);
+    vline(ACS_VLINE, LINES - TOPLINE - 1);
 
-    mvprintw(18, 68, "bands: %s", bm_config.allband ? "all" : "own");
-    mvprintw(19, 68, "modes: %s", bm_config.allmode ? "all" : "own");
-    mvprintw(20, 68, "dupes: %s", bm_config.showdupes ? "yes" : "no");
-    mvprintw(21, 68, "onl.ml: %s", bm_config.onlymults ? "yes" : "no");
+    mvprintw(LASTLINE - 5, 67, " bands: %s", bm_config.allband ? "all" : "own");
+    mvprintw(LASTLINE - 4, 67, " modes: %s", bm_config.allmode ? "all" : "own");
+    mvprintw(LASTLINE - 3, 67, " dupes: %s", bm_config.showdupes ? "yes" : "no");
+    mvprintw(LASTLINE - 2, 67, " onl.ml: %s", bm_config.onlymults ? "yes" : "no");
 
     attrset(COLOR_PAIR(CB_NEW) | A_STANDOUT);
-    mvprintw(22, 69, "MULTI");
+    mvprintw(LASTLINE - 1, 67, "  MULTI");
 
     attrset(COLOR_PAIR(CB_NEW) | A_BOLD);
     printw(" NEW");
 
     attrset(COLOR_PAIR(CB_NORMAL));
-    mvprintw(23, 67, "SPOT");
+    mvprintw(LASTLINE, 67, "SPOT");
 
     attrset(COLOR_PAIR(CB_OLD));
     printw(" OLD");
@@ -571,7 +577,7 @@ char *format_spot(spot *data) {
  */
 void show_spot(spot *data) {
     attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
-    printw("%7.1f %c ", (float)(data->freq / 1000.),
+    printw("%7.1f %c ", data->freq / 1000.,
 	   (data->node == thisnode ? '*' : data->node));
 
     char *temp = format_spot(data);
@@ -600,8 +606,8 @@ void show_spot_on_qrg(spot *data) {
  */
 void next_spot_position(int *y, int *x) {
     *y += 1;
-    if (*y == 24) {
-	*y = 14;
+    if (*y == LASTLINE + 1) {
+	*y = TOPLINE;
 	*x += SPOT_COLUMN_WIDTH;
     }
 }
@@ -613,8 +619,8 @@ void next_spot_position(int *y, int *x) {
  * Otherwise calculate center frequency from band and mode
  * as middle value of the band/mode corners.
  */
-float bm_get_center(int band, int mode) {
-    float centerfrequency;
+freq_t bm_get_center(int band, int mode) {
+    freq_t centerfrequency;
 
     if (trx_control)
 	return freq;		/* return freq from rig */
@@ -627,7 +633,7 @@ float bm_get_center(int band, int mode) {
     } else {
 	centerfrequency = (cwcorner[band] + ssbcorner[band]) / 2.;
     }
-    return centerfrequency / 1000.;
+    return centerfrequency;
 }
 
 
@@ -671,7 +677,6 @@ void bandmap_show() {
     int bm_x, bm_y;
     int i, j;
     short dupe, multi;
-    float centerfrequency;
 
     if (!bm_initialized) {
 	bm_init();
@@ -728,8 +733,8 @@ void bandmap_show() {
 
     getyx(stdscr, cury, curx);		/* remember cursor */
 
-    /* start in line 14, column 0 */
-    bm_y = 14;
+    /* start in TOPLINE, column 0 */
+    bm_y = TOPLINE;
     bm_x = 0;
 
     /* clear space for bandmap */
@@ -739,7 +744,7 @@ void bandmap_show() {
     for (j = 0; j < 67; j++)
 	addch(' ');
 
-    for (i = bm_y + 1; i < bm_y + 10; i++) {
+    for (i = bm_y + 1; i < LASTLINE + 1; i++) {
 	move(i, 0);
 	for (j = 0; j < 80; j++)
 	    addch(' ');
@@ -760,13 +765,13 @@ void bandmap_show() {
     unsigned int on_qrg = 0;
     unsigned int startindex, stopindex;
 
-    centerfrequency = bm_get_center(bandinx, trxmode);
+    const freq_t centerfrequency = bm_get_center(bandinx, trxmode);
 
     /* calc number of spots below your current QRG */
     for (i = 0; i < spots->len; i++) {
 	data = g_ptr_array_index(spots, i);
 
-	if (data->freq <= (centerfrequency * 1000 - TOLERANCE))
+	if (data->freq <= centerfrequency - TOLERANCE)
 	    below_qrg++;
 	else
 	    break;
@@ -776,7 +781,7 @@ void bandmap_show() {
     if (below_qrg < spots->len) {
 	data = g_ptr_array_index(spots, below_qrg);
 
-	if (!(data->freq > centerfrequency * 1000 + TOLERANCE))
+	if (!(data->freq > centerfrequency + TOLERANCE))
 	    on_qrg = 1;
     }
 
@@ -785,18 +790,18 @@ void bandmap_show() {
 	unsigned int max_below;
 	unsigned int above_qrg = spots->len - below_qrg - on_qrg;
 
-	if (above_qrg < 14) {
-	    max_below = 30 - above_qrg - 1;
+	if (above_qrg < ((NR_SPOTS - 1) / 2)) {
+	    max_below = NR_SPOTS - above_qrg - 1;
 	} else
-	    max_below = 15;
+	    max_below = NR_SPOTS / 2;
 
 	startindex = (below_qrg < max_below) ? 0 : (below_qrg - max_below);
     }
 
     /* calculate the index+1 of the last spot to show */
-    stopindex  = (spots->len < startindex + 30 - (1 - on_qrg))
+    stopindex  = (spots->len < startindex + NR_SPOTS - (1 - on_qrg))
 		 ? spots->len
-		 : (startindex + 30 - (1 - on_qrg));
+		 : (startindex + NR_SPOTS - (1 - on_qrg));
 
     /* correct calculations if we have no rig frequency to show */
     if (trx_control == 0) {
@@ -822,7 +827,7 @@ void bandmap_show() {
 	move(bm_y, bm_x);
 	attrset(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 	if (!on_qrg) {
-	    printw("%7.1f   %s", centerfrequency,  "============");
+	    printw("%7.1f   %s", centerfrequency / 1000.0,  "============");
 	} else {
 	    show_spot_on_qrg(g_ptr_array_index(spots, below_qrg));
 	}
@@ -854,7 +859,7 @@ void bm_menu() {
 
     attrset(COLOR_PAIR(C_LOG) | A_STANDOUT);
     mvprintw(13, 0, "  Toggle <B>and, <M>ode, <D>upes or <O>nly multi filter");
-    printw(" | any other - leave");
+    printw(" | any other - leave ");
 
     c = toupper(key_get());
     switch (c) {
@@ -955,7 +960,7 @@ spot *bandmap_lookup(char *partialcall) {
  * 		after use).
  */
 
-spot *bandmap_next(unsigned int upwards, unsigned int freq) {
+spot *bandmap_next(unsigned int upwards, freq_t freq) {
     spot *result = NULL;
 
     if (spots->len > 0) {
@@ -1041,7 +1046,7 @@ char *qtc_format(char *call) {
  * \param 	dest - place to put the call in
  * \param 	freq - the frequency where to look for a spot
  */
-void get_spot_on_qrg(char *dest, float freq) {
+void get_spot_on_qrg(char *dest, freq_t freq) {
 
     *dest = '\0';
 
@@ -1054,7 +1059,7 @@ void get_spot_on_qrg(char *dest, float freq) {
 	    spot *data;
 	    data = g_ptr_array_index(spots, i);
 
-	    if ((fabs(data->freq - freq * 1000) < TOLERANCE) &&
+	    if ((fabs(data->freq - freq) < TOLERANCE) &&
 		    (!bm_config.skipdupes || data->dupe == 0)) {
 		strcpy(dest, data->call);
 		break;
