@@ -42,6 +42,7 @@
 #include "cleanup.h"
 #include "cw_utils.h"
 #include "edit_last.h"
+#include "err_utils.h"
 #include "deleteqso.h"
 #include "getctydata.h"
 #include "gettxinfo.h"
@@ -75,17 +76,9 @@
 
 #include <math.h>
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
-
 #define TUNE_UP 6	/* tune up for 6 s (no more than 10) */
 
-void send_bandswitch(int freq);
+void send_bandswitch(freq_t freq);
 int autosend(void);
 int plain_number(char *str);
 void handle_bandswitch(int direction);
@@ -96,9 +89,9 @@ extern int bandinx;
 extern char band[NBANDS][4];
 extern int contest;
 extern int dxped;
-extern float freq;
+extern freq_t freq;
 extern int trx_control;
-extern float bandfrequency[];
+extern freq_t bandfrequency[];
 
 
 /** callsign input loop
@@ -123,7 +116,7 @@ int callinput(void) {
     extern int cluster;
     extern int announcefilter;
     extern char ph_message[14][80];
-    extern float mem;
+    extern freq_t mem;
     extern SCREEN *mainscreen;
     extern int simulator;
     extern int simulator_mode;
@@ -149,7 +142,7 @@ int callinput(void) {
     extern int bmautograb;
     extern int digikeyer;
 
-    static float freqstore;		/* qrg during last callsign input
+    static freq_t freqstore;		/* qrg during last callsign input
 					   character, 0 if grabbed,
 					   used to decide if a call in input
 					   field was entered by hand or
@@ -159,7 +152,7 @@ int callinput(void) {
 
     struct grab_t {
 	enum grabstate_t state;
-	float spotfreq;
+	freq_t spotfreq;
 	char call[15];
     };
 
@@ -168,7 +161,7 @@ int callinput(void) {
 
 
     int cury, curx;
-    int j, ii, t, x = 0;
+    int j, t, x = 0;
     char instring[2] = { '\0', '\0' };
     static int lastwindow;
 
@@ -206,7 +199,7 @@ int callinput(void) {
 	     * from frequency and if so add call to spot list */
 	    if (bmautoadd != 0 && freqstore != 0) {
 		if (strlen(hiscall) >= 3) {
-		    if (fabsf(freq - freqstore) > 0.1) {
+		    if (fabsf(freq - freqstore) > 500) {
 			add_to_spots(hiscall, freqstore);
 			hiscall[0] = '\0';
 			HideSearchPanel();
@@ -234,7 +227,7 @@ int callinput(void) {
 
 	    /* wait till freq of grabbed spot is reported back from rig.
 	     * Then go to 'reached' state' */
-	    if (grab.state == IN_PROGRESS && fabs(freq - grab.spotfreq) <= 0.1)
+	    if (grab.state == IN_PROGRESS && fabs(freq - grab.spotfreq) <= 100)
 		grab.state = REACHED;
 
 	    /* Check if we tune away from old freq before a grabbed spot is
@@ -242,7 +235,7 @@ int callinput(void) {
 
 	    /* if we have grabbed a call from spot list and tune away
 	     * then forget about it */
-	    if (fabsf(freq - grab.spotfreq) > 0.1 && grab.state == REACHED) {
+	    if (fabsf(freq - grab.spotfreq) > 500 && grab.state == REACHED) {
 		grab.state = NONE;
 		hiscall[0] = '\0';
 		printcall();
@@ -260,27 +253,6 @@ int callinput(void) {
 
 	/* special handling of some keycodes if call field is empty */
 	if (*hiscall == '\0') {
-	    if ((x == '+') && (*hiscall == '\0') && (ctcomp == 0)) {
-		/* switch to other mode */
-		if (cqmode == CQ) {
-		    cqmode = S_P;
-		} else
-		    cqmode = CQ;
-
-		/* and show new mode */
-		attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-
-		if (cqmode == CQ) {
-		    mvprintw(0, 2, "Log     ");
-		    strcpy(mode, "Log     ");
-		} else {
-		    mvprintw(0, 2, "S&P     ");
-		    strcpy(mode, "S&P     ");
-		}
-		cleanup();
-
-	    }
-
 	    // <Enter>, sends CQ message (F1), starts autoCQ, or sends S&P message.
 	    if ((x == '\n' || x == KEY_ENTER) && *hiscall == '\0') {
 		if (cqmode == CQ) {
@@ -309,19 +281,43 @@ int callinput(void) {
 
 	switch (x) {
 
-	    // Plus, in CT mode send exchange, log QSO, no message sent.
+	    // Plus (+)
+	    // - in non-CT mode switch to other mode (CQ <-> S&P)
+	    // - in CT mode send exchange, log QSO, no message sent.
 	    case '+': {
-		if ((ctcomp != 0) && (strlen(hiscall) > 2)) {
-		    send_standard_message(2);
+		if (!ctcomp) {
 
-		    if (((cqww == 1) || (wazmult == 1))
-			    && (*comment == '\0'))
-			strcpy(comment, cqzone);
+		    /* switch to other mode */
+		    if (cqmode == CQ) {
+			cqmode = S_P;
+		    } else
+			cqmode = CQ;
 
-		    if ((itumult == 1) && (*comment == '\0'))
-			strcpy(comment, ituzone);
-		    x = 92;	// '\'
+		    /* and show new mode */
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
+		    if (cqmode == CQ) {
+			mvprintw(0, 2, "Log     ");
+			strcpy(mode, "Log     ");
+		    } else {
+			mvprintw(0, 2, "S&P     ");
+			strcpy(mode, "S&P     ");
+		    }
+
+		} else {
+
+		    if (strlen(hiscall) > 2) {
+			send_standard_message(2);
+
+			if (((cqww == 1) || (wazmult == 1))
+				&& (*comment == '\0'))
+			    strcpy(comment, cqzone);
+
+			if ((itumult == 1) && (*comment == '\0'))
+			    strcpy(comment, ituzone);
+			x = '\\';   // key for logging QSO without message
+
+		    }
 		}
 		break;
 	    }
@@ -382,7 +378,7 @@ int callinput(void) {
 
 		nicebox(1, 1, 2, 12, "Cw");
 		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-		mvprintw(2, 2, "Speed:   %2d ", GetCWSpeed());
+		mvprintw(2, 2, "Speed:   %2u ", GetCWSpeed());
 		mvprintw(3, 2, "Weight: %3d ", weight);
 		refreshp();
 
@@ -417,7 +413,7 @@ int callinput(void) {
 		    while (x != 27) {	//escape
 			nicebox(1, 1, 2, 12, "Cw");
 			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-			mvprintw(2, 2, "Speed:   %2d ", GetCWSpeed());
+			mvprintw(2, 2, "Speed:   %2u ", GetCWSpeed());
 			mvprintw(3, 2, "Weight: %3d ", weight);
 			printcall();
 			refreshp();
@@ -427,12 +423,12 @@ int callinput(void) {
 			    speedup();
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
-			    mvprintw(0, 14, "%2d", GetCWSpeed());
+			    mvprintw(0, 14, "%2u", GetCWSpeed());
 
 			} else if (x == KEY_DOWN) {
 			    speeddown();
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-			    mvprintw(0, 14, "%2d", GetCWSpeed());
+			    mvprintw(0, 14, "%2u", GetCWSpeed());
 
 			} else
 			    x = 27;	// <Escape>
@@ -464,7 +460,7 @@ int callinput(void) {
 		    speedup();
 
 		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-		    mvprintw(0, 14, "%2d", GetCWSpeed());
+		    mvprintw(0, 14, "%2u", GetCWSpeed());
 		}
 
 		break;
@@ -488,7 +484,7 @@ int callinput(void) {
 		    speeddown();
 
 		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-		    mvprintw(0, 14, "%2d", GetCWSpeed());
+		    mvprintw(0, 14, "%2u", GetCWSpeed());
 		}
 		break;
 	    }
@@ -553,14 +549,14 @@ int callinput(void) {
 	    case '#': {
 		if (mem == 0.0) {
 		    mem = freq;
-		    mvprintw(14, 68, "MEM: %7.1f", mem);
+		    mvprintw(14, 67, " MEM: %7.1f", mem / 1000.);
 		} else {
 		    freq = mem;
 
-		    set_outfreq(mem * 1000);
+		    set_outfreq(mem);
 
 		    mem = 0.0;
-		    mvprintw(14, 68, "            ");
+		    mvprintw(14, 67, "             ");
 		}
 		mvprintw(29, 12, " ");
 		mvprintw(29, 12, "");
@@ -681,20 +677,8 @@ int callinput(void) {
 		    cluster = CLUSTER;	// alt-A
 		    announcefilter = FILTER_ALL;
 		} else if (cluster == CLUSTER) {
-		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-
-		    for (ii = 14; ii < 24; ii++)
-			mvprintw(ii, 0, backgrnd_str);
-		    refreshp();
-
 		    cluster = MAP;
 		} else if (cluster == MAP) {
-		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-
-		    for (ii = 14; ii < 24; ii++)
-			mvprintw(ii, 0, backgrnd_str);
-		    refreshp();
-
 		    cluster = NOCLUSTER;
 		}
 
@@ -927,10 +911,10 @@ int callinput(void) {
 
 	    // Ctrl-G (^G), grab next DX spot from bandmap.
 	    case 7: {
-		double f = grab_next();
+		freq_t f = grab_next();
 		if (f > 0.0) {
 		    grab.state = IN_PROGRESS;
-		    grab.spotfreq = f / 1000.;
+		    grab.spotfreq = f;
 		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		    mvprintw(0, 2, "%s", mode);
 		    freqstore = 0;
@@ -944,7 +928,7 @@ int callinput(void) {
 		double f = grabspot();
 		if (f > 0.0) {
 		    grab.state = IN_PROGRESS;
-		    grab.spotfreq = f / 1000.;
+		    grab.spotfreq = f;
 		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		    mvprintw(0, 2, "%s", mode);
 		    freqstore = 0;
@@ -1223,9 +1207,7 @@ int autosend() {
 int play_file(char *audiofile) {
 
     extern int txdelay;
-#ifdef HAVE_LIBHAMLIB
     extern unsigned char rigptt;
-#endif
 
     int fd;
     char playcommand[120];
@@ -1234,7 +1216,7 @@ int play_file(char *audiofile) {
 	return (0);
 
     if ((fd = open(audiofile, O_RDONLY, 0664)) < 0) {
-	mvprintw(24, 0, "cannot open sound file %s!", audiofile);
+	TLF_LOG_INFO("cannot open sound file %s!", audiofile);
     } else {
 	close(fd);
 	if (access("./play_vk", X_OK) == 0) {
@@ -1242,41 +1224,33 @@ int play_file(char *audiofile) {
 	} else {
 	    sprintf(playcommand, "play_vk %s", audiofile);
 	}
-#ifdef HAVE_LIBHAMLIB
 	/* CAT PTT wanted and available, use it. */
 	if (rigptt == 0x03) {
 	    /* Request PTT On */
 	    rigptt |= (1 << 3);		/* 0x0b */
 	} else {		/* Fall back to netkeyer interface */
-#endif
 	    netkeyer(K_PTT, "1");	// ptt on
-#ifdef HAVE_LIBHAMLIB
 	}
-#endif
 
 	usleep(txdelay * 1000);
 	IGNORE(system(playcommand));;
 	printcall();
 
-#ifdef HAVE_LIBHAMLIB
 	/* CAT PTT wanted, available, and active. */
 	if (rigptt == 0x07) {
 
 	    /* Request PTT Off */
 	    rigptt |= (1 << 4);		/* 0x17 */
 	} else {		/* Fall back to netkeyer interface */
-#endif
 	    netkeyer(K_PTT, "0");	// ptt off
-#ifdef HAVE_LIBHAMLIB
 	}
-#endif
     }
 
-    return (0);
+    return 0;
 }
 
 
-void send_bandswitch(int freq) {
+void send_bandswitch(freq_t freq) {
 
     extern int use_bandoutput;
     extern int bandinx;
@@ -1285,44 +1259,47 @@ void send_bandswitch(int freq) {
     char outnibble[3];
     int bandswitch = 0;
 
-    if (use_bandoutput == 1) {
-	if (freq > 15) {	// cannot be a freq...
-	    switch ((int) freq) {
-		case 1800 ... 2000:
-		    bandswitch = 1;
-		    break;
-		case 3500 ... 4000:
-		    bandswitch = 2;
-		    break;
-		case 7000 ... 7300:
-		    bandswitch = 3;
-		    break;
-		case 10100 ... 10150:
-		    bandswitch = 4;
-		    break;
-		case 14000 ... 14350:
-		    bandswitch = 5;
-		    break;
-		case 18068 ... 18168:
-		    bandswitch = 6;
-		    break;
-		case 21000 ... 21450:
-		    bandswitch = 7;
-		    break;
-		case 24890 ... 24990:
-		    bandswitch = 8;
-		    break;
-		case 28000 ... 29700:
-		    bandswitch = 9;
-	    }
-	} else			// use the bandinx
-	    bandswitch = bandinx + 1;
-
-	bandswitch = bandindexarray[bandswitch];
-
-	sprintf(outnibble, "%d", bandswitch);
-	netkeyer(K_SWITCH, outnibble);
+    if (!use_bandoutput) {
+	return;
     }
+
+    const int khz = (int)(freq / 1000.0);
+    if (khz > 15) {	// looks like a freq...
+	switch (khz) {
+	    case 1800 ... 2000:
+		bandswitch = 1;
+		break;
+	    case 3500 ... 4000:
+		bandswitch = 2;
+		break;
+	    case 7000 ... 7300:
+		bandswitch = 3;
+		break;
+	    case 10100 ... 10150:
+		bandswitch = 4;
+		break;
+	    case 14000 ... 14350:
+		bandswitch = 5;
+		break;
+	    case 18068 ... 18168:
+		bandswitch = 6;
+		break;
+	    case 21000 ... 21450:
+		bandswitch = 7;
+		break;
+	    case 24890 ... 24990:
+		bandswitch = 8;
+		break;
+	    case 28000 ... 29700:
+		bandswitch = 9;
+	}
+    } else			// use the bandinx
+	bandswitch = bandinx + 1;
+
+    bandswitch = bandindexarray[bandswitch];
+
+    sprintf(outnibble, "%d", bandswitch);
+    netkeyer(K_SWITCH, outnibble);
 }
 
 
@@ -1348,7 +1325,7 @@ void handle_bandswitch(int direction) {
 
     if (trx_control) {
 	freq = bandfrequency[bandinx]; // TODO: is this needed?
-	set_outfreq(bandfrequency[bandinx] * 1000);
+	set_outfreq(bandfrequency[bandinx]);
     }
 
     send_bandswitch(bandinx);
