@@ -35,6 +35,7 @@
 #include "changepars.h"
 #include "clear_display.h"
 #include "editlog.h"
+#include "err_utils.h"
 #include "fldigixmlrpc.h"
 #include "gettxinfo.h"
 #include "ignore_unused.h"
@@ -50,6 +51,7 @@
 #include "readqtccalls.h"
 #include "rules.h"
 #include "scroll_log.h"
+#include "searchlog.h"
 #include "sendbuf.h"
 #include "set_tone.h"
 #include "show_help.h"
@@ -59,19 +61,11 @@
 #include "ui_utils.h"
 #include "writecabrillo.h"
 #include "writeparas.h"
-
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
-
-#define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
+#include "addmult.h"
 
 
 int debug_tty(void);
+void wipe_display();
 
 int changepars(void) {
 
@@ -101,8 +95,9 @@ int changepars(void) {
     extern char sc_volume[];
     extern int cwstart;
     extern int digikeyer;
+    extern int cqmode;
 
-    char parameterstring[20];
+    char parameterstring[20] = "";
     char parameters[52][19];
     char cmdstring[80];
     int i, k, x, nopar = 0;
@@ -155,7 +150,8 @@ int changepars(void) {
     strcpy(parameters[41], "SYNC");
     strcpy(parameters[42], "RESCORE");
     strcpy(parameters[43], "SCVOLUME");
-    strcpy(parameters[44], "SCAN");
+    //strcpy(parameters[44], "SCAN");	/* 05jan18 no longer supported */
+    strcpy(parameters[44], "");
     strcpy(parameters[45], "DEBUG");
     strcpy(parameters[46], "MINITERM");
     strcpy(parameters[47], "RTTY");
@@ -170,13 +166,11 @@ int changepars(void) {
     attron(COLOR_PAIR(C_HEADER));
     mvprintw(12, 29, "PARAMETER?  ");
     refreshp();
-
+    usleep(400000);
     mvprintw(12, 29, "            ");
-    mvprintw(12, 29, "");
-    refreshp();
 
     echo();
-    getstr(parameterstring);
+    mvgetnstr(12, 29, parameterstring, 19);
     noecho();
 
     for (k = 0; parameterstring[k]; k++)
@@ -325,7 +319,6 @@ int changepars(void) {
 		zonedisplay = 1;
 	    else {
 		zonedisplay = 0;
-
 	    }
 
 	    break;
@@ -356,7 +349,7 @@ int changepars(void) {
 
 	    break;
 	}
-	case 24:			/* SET PARAMETERS */
+	case 24:		/* SET PARAMETERS */
 	case 29: {		/* CFG PARAMETERS */
 	    clear();
 	    if (editor == EDITOR_JOE) {
@@ -375,8 +368,7 @@ int changepars(void) {
 	    read_logcfg();
 	    read_rules();	/* also reread rules file */
 	    writeparas();
-	    mvprintw(24, 0, "Logcfg.dat loaded, parameters written..");
-	    refreshp();
+	    TLF_LOG_INFO("Logcfg.dat loaded, parameters written.");
 	    clear_display();
 	    break;
 	}
@@ -449,22 +441,36 @@ int changepars(void) {
 	    break;
 	}
 	case 34: {		/* SIMULATOR  */
-	    if (simulator == 0) {
-		simulator = 1;
-		if (ctcomp == 1) {
-		    mvprintw(13, 19,
-			     "The simulator only works in TRmode. Switching to TRmode");
-		    ctcomp = 0;
-		} else
-		    mvprintw(13, 29, "Simulator on");
+	    if (cqww != 1) {
+		TLF_LOG_INFO(
+		    "Simulator mode is only supported for CQWW contest!");
+		break;
+	    }
 
-		refreshp();
+	    if (callmaster == NULL) {
+		TLF_LOG_INFO(
+		    "Simulator mode needs callmaster database");
+		break;
+	    }
+
+	    if (simulator == 0) {
+
+		simulator = 1;
+		cqmode = CQ;
+		if (ctcomp == 1) {
+		    TLF_LOG_INFO(
+			"The simulator only works in TRmode. Switching to TRmode");
+		    ctcomp = 0;
+		} else {
+		    mvprintw(13, 29, "Simulator on");
+		    refreshp();
+		    sleep(1);
+		}
 
 		if (cwkeyer == NET_KEYER) {
 
 		    if (netkeyer(K_WORDMODE, NULL) < 0) {
-			mvprintw(24, 0,
-				 "keyer not active; switching to SSB");
+			TLF_LOG_INFO("keyer not active; switching to SSB");
 			trxmode = SSBMODE;
 			clear_display();
 		    }
@@ -473,17 +479,16 @@ int changepars(void) {
 		simulator = 0;
 		mvprintw(13, 29, "Simulator off");
 		refreshp();
+		sleep(1);
 
 		if (cwkeyer == NET_KEYER) {
 
 		    if (netkeyer(K_RESET, NULL) < 0) {
-			mvprintw(24, 0,
-				 "keyer not active; switching to SSB");
+			TLF_LOG_INFO("keyer not active; switching to SSB");
 			trxmode = SSBMODE;
 			clear_display();
 		    }
 		}
-
 	    }
 	    break;
 	}
@@ -631,14 +636,6 @@ int changepars(void) {
 	    clear_display();
 	    break;
 	}
-	case 44: {		/* SCAN */
-	    int currentterm = miniterm;
-	    miniterm = 0;
-	    testaudio();
-	    clear_display();
-	    miniterm = currentterm;
-	    break;
-	}
 	case 45: {		/* DEBUG */
 	    debug_tty();
 	    clear_display();
@@ -697,7 +694,7 @@ int changepars(void) {
 	    break;
 
 	}
-        case 51: {              /* FLDIGI - turn on/off */
+	case 51: {              /* FLDIGI - turn on/off */
 	    if (digikeyer == FLDIGI) {
 		if (fldigi_toggle()) {
 		    fldigi_clear_connerr();
@@ -737,7 +734,7 @@ int changepars(void) {
 
 /* -------------------------------------------------------------- */
 
-int networkinfo(void) {
+void networkinfo(void) {
 
     extern int use_bandoutput;
     extern int recv_packets;
@@ -754,15 +751,9 @@ int networkinfo(void) {
     extern char *rigportname;
     extern char logfile[];
 
-    int i, j, inode;
+    int inode;
 
-    clear();
-
-    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
-
-    for (j = 0; j <= 24; j++)
-	mvprintw(j, 0,
-		 "                                                                                ");
+    wipe_display();
 
     if (lan_active == 1)
 	mvprintw(1, 10, "Network status: on");
@@ -800,38 +791,24 @@ int networkinfo(void) {
 
     (void)key_get();
 
-    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
-    for (i = 0; i <= 24; i++)
-	mvprintw(i, 0,
-		 "                                                                                ");
-
     clear_display();
-
-    return (0);
-
+    return;
 }
 
 /* -------------------------------------------------------------- */
 
-int multiplierinfo(void) {
+void multiplierinfo(void) {
 
     extern int arrlss;
     extern int serial_section_mult;
     extern int sectn_mult;
     extern struct mults_t multis[MAX_MULTS];
     extern int nr_multis;
-    extern GPtrArray *mults_possible;
 
     int j, k, vert, hor, cnt, found;
     char mprint[50];
 
-    clear();
-
-    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
-
-    for (j = 0; j <= 24; j++)
-	mvprintw(j, 0,
-		 "                                                                                ");
+    wipe_display();
 
     if (arrlss == 1) {
 	int attributes;
@@ -842,14 +819,14 @@ int multiplierinfo(void) {
 	cnt = 0;
 	for (vert = 9; vert < 18; vert++) {
 
-	    if (cnt >= mults_possible->len)
+	    if (cnt >= get_mult_count())
 		break;
 
 	    for (hor = 5; hor < 15; hor++) {
-		if (cnt >= mults_possible->len)
+		if (cnt >= get_mult_count())
 		    break;
 
-		g_strlcpy(chmult, MULTS_POSSIBLE(cnt), sizeof(chmult));
+		g_strlcpy(chmult, get_mult(cnt), sizeof(chmult));
 
 		/* check if in worked multis */
 		found = 0;
@@ -867,7 +844,7 @@ int multiplierinfo(void) {
 
 		attron(modify_attr(attributes));
 
-		g_strlcpy(mprint, MULTS_POSSIBLE(cnt), 5);
+		g_strlcpy(mprint, get_mult(cnt), 5);
 		mvprintw(vert, hor * 4, "%s", mprint);
 
 		cnt++;
@@ -882,24 +859,24 @@ int multiplierinfo(void) {
 	mvprintw(0, 30, "REMAINING SECTIONS");
 	cnt = 0;
 	for (vert = 2; vert < 22; vert++) {
-	    if (cnt >= mults_possible->len)
+	    if (cnt >= get_mult_count())
 		break;
 
 	    for (hor = 0; hor < 7; hor++) {
-		if (cnt >= mults_possible->len)
+		if (cnt >= get_mult_count())
 		    break;
 
 		worked_at = 0;
 
 		/* lookup if already worked */
 		for (k = 0; k < nr_multis; k++) {
-		    if (strstr(multis[k].name, MULTS_POSSIBLE(cnt)) != NULL) {
+		    if (strstr(multis[k].name, get_mult(cnt)) != NULL) {
 			worked_at = multis[k].band;
 			break;
 		    }
 		}
 
-		tmp = g_strndup(MULTS_POSSIBLE(cnt), 4);
+		tmp = g_strndup(get_mult(cnt), 4);
 		sprintf(mprint, "%-4s", tmp);
 		g_free(tmp);
 
@@ -926,16 +903,8 @@ int multiplierinfo(void) {
 
     (void)key_get();
 
-    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
-
-    for (j = 0; j <= 24; j++)
-	mvprintw(j, 0,
-		 "                                                                                ");
-
     clear_display();
-
-    return (0);
-
+    return;
 }
 
 /* ------------------------- radio link debug ------------------------------ */
@@ -1101,3 +1070,14 @@ int debug_tty(void) {
 
     return (0);
 }
+
+
+void wipe_display() {
+    int j;
+    extern char backgrnd_str[];
+
+    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
+
+    for (j = 0; j < LINES; j++)
+	mvprintw(j, 0, backgrnd_str);
+}
