@@ -31,6 +31,7 @@
 
 #include "clear_display.h"
 #include "deleteqso.h"
+#include "err_utils.h"
 #include "ignore_unused.h"
 #include "printcall.h"
 #include "qtcutil.h"
@@ -39,6 +40,7 @@
 #include "tlf_curses.h"
 #include "scroll_log.h"
 #include "ui_utils.h"
+#include "addcall.h"
 
 #define QTCRECVCALLPOS 30
 #define QTCSENTCALLPOS 35
@@ -143,9 +145,7 @@ void delete_qso(void) {
 
 	if ((lfile = open(logfile, O_RDWR)) < 0) {
 
-	    mvprintw(24, 0, "I can not find the logfile...");
-	    refreshp();
-	    sleep(2);
+	    TLF_LOG_WARN("I can not find the logfile...");
 	} else {
 
 	    fstat(lfile, &statbuf);
@@ -169,8 +169,9 @@ void delete_qso(void) {
 	    fsync(lfile);
 	    close(lfile);
 
-	    if (qsos[nr_qsos][0] != ';') {
-		band_score[bandinx]--;
+	    if (qsos[nr_qsos-1][0] != ';') {
+		int band = get_band(qsos[nr_qsos-1]);
+		band_score[band]--;
 		qsonum--;
 		qsonr_to_str();
 	    }
