@@ -21,39 +21,49 @@
 #ifndef DXCC_H
 #define DXCC_H
 
+#include <stdbool.h>
+
 typedef struct {
-	char *pfx;
-	short cq;
-	short itu;
-	short dxcc_index;
+    char *pfx;
+    short cq;
+    short itu;
+    short dxcc_index;
+    float lat;
+    float lon;
+    char *continent;
+    float timezone;
+    bool exact;
 } prefix_data;
 
 typedef struct {
-	char *countryname;
-	short cq;
-	short itu;
-	char *continent;
-	float lat;
-	float lon;
-	float timezone;
-	char *pfx;
-	char starred;
+    char *countryname;
+    short cq;
+    short itu;
+    char *continent;
+    float lat;
+    float lon;
+    float timezone;
+    char *pfx;
+    bool starred;
 } dxcc_data;
 
+extern bool have_exact_matches;
+
 void prefix_init(void);
 
-int prefix_count(void);
+unsigned int prefix_count(void);
 
-prefix_data *prefix_by_index(int index);
+prefix_data *prefix_by_index(unsigned int index);
 
-void prefix_add (char *pfxstr);
+void prefix_add(char *pfxstr);
 
 void dxcc_init(void);
 
-int dxcc_count(void);
+unsigned int dxcc_count(void);
 
-dxcc_data *dxcc_by_index(int index);
+dxcc_data *dxcc_by_index(unsigned int index);
 
-void dxcc_add (char * dxcc_line);
+void dxcc_add(char *dxcc_line);
 
+int load_ctydata(char *filename);
 #endif 	/* DXCC_H */
