@@ -28,10 +28,9 @@
 #include <glib.h>
 #include <ctype.h>
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
+#include <config.h>
 
+#include "err_utils.h"
 #include "fldigixmlrpc.h"
 #include "printcall.h"
 #include "ui_utils.h"
@@ -46,9 +45,7 @@
 # include <xmlrpc-c/client_global.h>
 #endif
 
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
+#include <hamlib/rig.h>
 
 #define NAME "Tlf"
 #define XMLRPCVERSION "1.0"
@@ -214,9 +211,7 @@ int fldigi_xmlrpc_query(xmlrpc_res *local_result, xmlrpc_env *local_env,
     if (connerr == 1 && use_fldigi == 1) {
 	if (connerrcnt == 10) {
 	    use_fldigi = 0;
-	    mvprintw(24, 0, "Fldigi: lost connection!\n");
-	    refreshp();
-	    sleep(1);
+	    TLF_LOG_WARN("Fldigi: lost connection!");
 	} else {
 	    connerrcnt++;
 	}
@@ -466,14 +461,12 @@ int fldigi_xmlrpc_get_carrier() {
     int rc;
     xmlrpc_res result;
     xmlrpc_env env;
-#ifdef HAVE_LIBHAMLIB
-    extern int rigmode;
+    extern rmode_t rigmode;
     extern int trx_control;
-    extern float freq;
+    extern freq_t freq;
     int signum;
     int modeshift;
     char fldigi_mode[6] = "";
-#endif
 
     rc = fldigi_xmlrpc_query(&result, &env, "modem.get_carrier", "");
     if (rc != 0) {
@@ -485,7 +478,6 @@ int fldigi_xmlrpc_get_carrier() {
     /* if mode == RTTY(R), and Hamlib configured, set VFO to new freq where the signal
      * will placed on 2210 Hz - the FSK center freq
      */
-#ifdef HAVE_LIBHAMLIB
     if (trx_control > 0) {
 	if (rigmode == RIG_MODE_RTTY || rigmode == RIG_MODE_RTTYR) {
 	    if (fldigi_var_carrier != CENTER_FREQ &&
@@ -504,7 +496,7 @@ int fldigi_xmlrpc_get_carrier() {
 
 	if (rigmode != RIG_MODE_NONE) {
 	    switch (rigmode) {
-                case RIG_MODE_USB:
+		case RIG_MODE_USB:
 		    signum = 1;
 		    modeshift = 85;
 		    strcpy(fldigi_mode, "USB");
@@ -550,13 +542,13 @@ int fldigi_xmlrpc_get_carrier() {
 	    /* also set the freq value in Fldigi FREQ block */
 	    rc = fldigi_xmlrpc_query(&result, &env,
 				     "rig.set_frequency", "f",
-				     (xmlrpc_double)((freq * 1000.0) - (fldigi_var_carrier)));
+				     (xmlrpc_double)(freq - fldigi_var_carrier));
 	    if (rc != 0) {
 		return -1;
 	    }
 	}
     }
-#endif
+
     return 0;
 #endif
 
