@@ -4,9 +4,7 @@
 
 #include <glib.h>
 
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
+#include <hamlib/rig.h>
 
 extern char qsos[MAX_QSOS][LOGLINELEN + 1];
 					// array of log lines of QSOs so far;
@@ -84,7 +82,6 @@ extern char continent[];
 extern char zone_export[];
 extern int itumult;
 
-extern GPtrArray *mults_possible;	/* growing array of possible mutlipliers */
 extern char ssexchange[];
 extern int shownewmult;
 extern char comment[];
@@ -99,7 +96,7 @@ extern int highqsonr;
 
 
 extern int trxmode;
-extern int rigmode;
+extern rmode_t rigmode;
 extern char lastqsonr[];
 extern int cqwwm2;
 extern char thisnode;
@@ -119,9 +116,7 @@ extern int three_point;
 extern int dxped;
 extern int addzone;
 extern int do_cabrillo;
-#ifdef HAVE_LIBHAMLIB
 extern rmode_t digi_mode;
-#endif
 
 extern char message[][80];
 extern char *digi_message[];
