@@ -31,6 +31,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 
+#include "err_utils.h"
 #include "lancode.h"
 #include "tlf.h"
 #include "tlf_curses.h"
@@ -55,8 +56,8 @@ struct sockaddr_in bc_address[MAXNODES];
 struct hostent *bc_hostbyname[MAXNODES];
 /* host names and UDP ports to send notifications to */
 char bc_hostaddress[MAXNODES][16];
-char bc_hostservice[MAXNODES][16] = { 
-	[0 ... MAXNODES - 1] = { [0 ... 15] = 0 } 
+char bc_hostservice[MAXNODES][16] = {
+    [0 ... MAXNODES - 1] = { [0 ... 15] = 0 }
 };
 char sendbuffer[256];
 int nodes = 0;
@@ -65,6 +66,8 @@ int send_error_limit[MAXNODES];
 //--------------------------------------
 /* default port to listen for incomming packets and to send packet to */
 char default_lan_service[16] = "6788";
+/* lan port parsed from config */
+int lan_port = 6788;
 
 int lan_active = 0;
 int send_error[MAXNODES];
@@ -74,7 +77,7 @@ int recv_error;
 int recv_packets;
 int buflen;
 char talkarray[5][62];
-float node_frequencies[MAXNODES];
+freq_t node_frequencies[MAXNODES];
 int lanqsos;
 char lastqsonr[5];
 int highqsonr;
@@ -85,6 +88,8 @@ int time_master;
 char thisnode = 'A'; 		/*  start with 'A' if not defined in
 				    logcfg.dat */
 
+extern char backgrnd_str[];
+
 //---------------------end lan globals --------------
 
 int resolveService(const char *service) {
@@ -92,7 +97,7 @@ int resolveService(const char *service) {
     service_ent = getservbyname(service, "udp");
     int port = 0;
     if (service_ent != NULL) {
-	port = service_ent->s_port;
+	port = ntohs(service_ent->s_port);
     } else if (strlen(service) > 0) {
 	port = atoi(service);
     }
@@ -106,6 +111,7 @@ int lanrecv_init(void) {
     if (lan_active == 0)
 	return (1);
 
+    sprintf(default_lan_service, "%d", lan_port);
     bzero(&lan_sin, sizeof(lan_sin));
     lan_sin.sin_family = AF_INET;
     lan_sin.sin_addr.s_addr = htonl(INADDR_ANY);
@@ -257,8 +263,7 @@ int lan_send(char *lanbuffer) {
 
 	if (bc_sendto_rc == -1) {
 	    if (send_error[node] >= (send_error_limit[node] + 10)) {
-		mvprintw(24, 0, "LAN: send problem...!");
-		refreshp();
+		TLF_LOG_INFO("LAN: send problem...!");
 		send_error_limit[node] += 10;
 	    } else
 		send_error[node]++;
@@ -333,14 +338,12 @@ int send_lan_message(int opcode, char *message) {
 }
 
 /* ----------------- send talk message ----------*/
-
-int talk(void) {
+void talk(void) {
 
     char talkline[61] = "";
 
-    mvprintw(24, 0,
-	     "                                                                           ");
-    mvprintw(24, 0, "T>");
+    mvprintw(LINES - 1, 0, backgrnd_str);
+    mvprintw(LINES - 1, 0, "T>");
     refreshp();
     echo();
     getnstr(talkline, 60);
@@ -352,16 +355,13 @@ int talk(void) {
 
     talkline[0] = '\0';
     attron(COLOR_PAIR(C_HEADER));
-    mvprintw(24, 0,
-	     "                                                                               ");
+    mvprintw(LINES - 1, 0, backgrnd_str);
     refreshp();
-
-    return (0);
 }
 
 /* ----------------- send freq. message ----------*/
 
-int send_freq(float freq) {
+int send_freq(freq_t freq) {
 
     extern int bandinx;
     extern int trx_control;
@@ -370,7 +370,7 @@ int send_freq(float freq) {
 
     if (trx_control == 1) {
 
-	sprintf(fbuffer, "%7.1f", freq);
+	sprintf(fbuffer, "%7.1f", freq / 1000.0);
     } else {
 	switch (bandinx) {
 
