@@ -36,7 +36,7 @@
 #include "recall_exchange.h"
 #include "searchlog.h"		// Includes glib.h
 #include "sendbuf.h"
-#include "sendqrg.h"		// Sets HAVE_LIBHAMLIB if enabled
+#include "sendqrg.h"
 #include "sendspcall.h"
 #include "set_tone.h"
 #include "tlf.h"
@@ -61,14 +61,11 @@ void logit(void) {
     extern char itustr[];
     extern int defer_store;
     extern int recall_mult;
-    extern int simulator;
-    extern int simulator_mode;
     extern int ctcomp;
     extern int wazmult;
     extern int itumult;
     extern int qsonum;
     extern int exchange_serial;
-    extern char tonestr[];
     extern int dxped;
     extern int sprint_mode;
 
@@ -111,6 +108,7 @@ void logit(void) {
 
 		if ((cqmode == CQ) && (contest == CONTEST)
 			&& (defer_store == 0)) {	/* CQ mode */
+
 		    send_standard_message(2);
 		    if (trxmode != CWMODE && trxmode != DIGIMODE) {
 			if (exchange_serial == 1)
@@ -118,13 +116,10 @@ void logit(void) {
 			refreshp();
 		    }
 
-		    if (simulator != 0) {
-			strcpy(tonestr, "700");
-			write_tone();
-			if (strstr(hiscall, "?") != NULL)
-			    simulator_mode = 3;
-			else
-			    simulator_mode = 2;
+		    if (strstr(hiscall, "?") != NULL) {
+			setSimulatorState(3);
+		    } else {
+			setSimulatorState(2);
 		    }
 
 		    if ((cqww == 1) || (wazmult == 1) || (itumult == 1)) {
@@ -140,11 +135,7 @@ void logit(void) {
 		    }
 
 		    if (recall_mult == 1) {
-			if (recall_exchange() == -1) {	/* get the power */
-			    comment[0] = '\0';
-
-			    refresh_comment();
-			}
+			recall_exchange();
 		    }
 
 		    defer_store = 1;
@@ -161,11 +152,7 @@ void logit(void) {
 			refresh_comment();
 
 		    } else if (recall_mult == 1) {
-			if (recall_exchange() == -1) {	/* get the mult */
-			    comment[0] = '\0';
-
-			    refresh_comment();
-			}
+			recall_exchange();
 		    }
 
 		    if (trxmode == CWMODE || trxmode == DIGIMODE)
@@ -176,8 +163,9 @@ void logit(void) {
 			    mvprintw(13, 29, "Serial number: %d", qsonum);
 			refreshp();
 		    }
-		    callreturn = 0;
+
 		    defer_store = 1;
+		    callreturn = 0;
 		}
 
 		if (defer_store == 1) {
@@ -186,12 +174,7 @@ void logit(void) {
 		} else if (defer_store > 1) {
 		    if ((cqmode == CQ) && (contest == CONTEST)) {
 			send_standard_message(CQ_TU_MSG);	/* send cq return */
-			if (trxmode == CWMODE || trxmode == DIGIMODE) {
-			    if (simulator != 0)
-				simulator_mode = 1;
-			    if (simulator != 0)
-				write_tone();
-			}
+			setSimulatorState(1);
 
 			defer_store = 0;
 
