@@ -16,44 +16,44 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 	/* ------------------------------------------------------------
- 	*        View Log using "less" function
- 	*
- 	*--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+*        View Log using "less" function
+*
+*--------------------------------------------------------------*/
 
 
 #include <stdlib.h>
 #include <string.h>
 
 #include "clear_display.h"
+#include "ignore_unused.h"
 #include "tlf.h"
 #include "tlf_curses.h"
 
 
-int logview(void)
-{
-	extern char logfile[];
-	extern char backgrnd_str[];
+int logview(void) {
+    extern char logfile[];
+    extern char backgrnd_str[];
 
-	char comstr[40]  = "";
-	int j, rc;
+    char comstr[40]  = "";
+    int j;
 
-	strcat(comstr,  "less  +G ");
-	strcat(comstr,  logfile);
-	rc=system(comstr);
-	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-	erase();
-	refreshp();
-	clear_display();
-	attron(COLOR_PAIR(C_LOG)  |  A_STANDOUT);
+    strcat(comstr,  "less  +G ");
+    strcat(comstr,  logfile);
 
-	for (j = 13 ;  j  <= 23 ; j++){
-		mvprintw(j, 0, backgrnd_str);
-	}
+    endwin();
+    IGNORE(system(comstr));;
+    refreshp();
 
-	refreshp();
+    clear_display();
+    attron(COLOR_PAIR(C_LOG)  |  A_STANDOUT);
 
+    for (j = 13 ;  j  <= 23 ; j++) {
+	mvprintw(j, 0, backgrnd_str);
+    }
 
-	return(0);
+    refreshp();
+
+    return (0);
 }
 
