@@ -26,6 +26,7 @@
 #include <string.h>
 #include <termios.h>
 #include <unistd.h>
+#include <argp.h>
 
 #include "addmult.h"
 #include "background_process.h"
@@ -52,7 +53,7 @@
 #include "rules.h"
 #include "scroll_log.h"
 #include "searchlog.h"		// Includes glib.h
-#include "sendqrg.h"		// Sets HAVE_LIBHAMLIB if enabled
+#include "sendqrg.h"
 #include "set_tone.h"
 #include "splitscreen.h"
 #include "startmsg.h"
@@ -60,13 +61,8 @@
 #include "ui_utils.h"
 #include "readcabrillo.h"
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
+#include <config.h>
+#include <hamlib/rig.h>
 
 
 SCREEN *mainscreen;
@@ -162,7 +158,6 @@ int isdupe = 0;			// 0 if nodupe -- for auto qso b4 (LZ3NY)
 int nob4 = 0;			// allow auto b4
 int ignoredupe = 0;
 int noautocq = 0;
-int emptydir = 0;
 int verbose = 0;
 int no_rst = 0;			/* 1 - do not use RS/RST */
 char myqra[7] = "";
@@ -187,9 +182,8 @@ char multsfile[80] = "";	/* name of file with a list of allowed
 char exchange_list[40] = "";
 int timeoffset = 0;
 int trxmode = CWMODE;
-int rigmode = 0;		/* RIG_MODE_NONE in hamlib/rig.h,
-				   but if hamlib not compiled,
-				   then no dependency */
+rmode_t  rigmode = RIG_MODE_NONE;
+
 int mixedmode = 0;
 char his_rst[4] = "599";
 char my_rst[4] = "599";
@@ -260,7 +254,7 @@ char *digi_message[sizeof(message) / sizeof(message[0])];
 char ph_message[14][80] = /**< Array of file names for voice keyer messages
 			   * See description of message[]
 			   */
-    { "", "", "", "", "", "", "", "", "", "", "", "", "", "" };
+{ "", "", "", "", "", "", "", "", "", "", "", "", "", "" };
 
 char qtc_recv_msgs[12][80] = {"QTC?\n", "QRV\n", "R\n", "", "TIME?\n", "CALL?\n", "NR?\n", "AGN\n", "", "QSL ALL\n", "", ""}; // QTC receive windowS Fx messages
 char qtc_send_msgs[12][80] = {"QRV?\n", "QTC sr/nr\n", "", "", "TIME\n", "CALL\n", "NR\n", "", "", "", "", ""}; // QTC send window Fx messages
@@ -285,7 +279,7 @@ int early_started = 0;			/**< 1 if sending call started early,
 char lastcall[20];
 char qsonrstr[5] = "0001";
 char band[NBANDS][4] =
-    { "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10", "???" };
+{ "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10", "???" };
 char comment[80];
 char mode[20] = "Log     ";
 char cqzone[3] = "";
@@ -311,10 +305,6 @@ int block_part = 0; 	/**< if 1 block the call autocompletion
 char para_word[80] = "LODNCFS:3C\n";	/* longcw, cluster, search, DE,
 					   contest, filter,  speed,  delay */
 char lastmsg[1000] = "";
-int scale_values[20] = {
-    40, 38, 36, 34, 32, 30, 28, 26, 24, 22, 20, 18, 16, 14, 12, 10, 8, 6,
-    4, 2
-};
 char sc_device[40] = "/dev/dsp";
 
 /*-------------------------------------keyer------------------------------*/
@@ -326,9 +316,7 @@ int keyer_backspace = 0;        // disabled
 
 char controllerport[80] = "/dev/ttyS0"; // for GMFSK or MFJ-1278
 char rttyoutput[120];		// where to GMFSK digimode output
-#ifdef HAVE_LIBHAMLIB
 rmode_t digi_mode = RIG_MODE_NONE;
-#endif
 
 int txdelay = 0;
 int weight = 0;
@@ -358,14 +346,12 @@ int bmautoadd = 0;
 int bmautograb = 0;
 
 /*-------------------------------------rigctl-------------------------------*/
-#ifdef HAVE_LIBHAMLIB
-rig_model_t myrig_model = 351;
+rig_model_t myrig_model = 351;  /* Ten-Tec Omni VI Plus */
 RIG *my_rig;			/* handle to rig (instance) */
 rmode_t rmode;			/* radio mode of operation */
 pbwidth_t width;
 vfo_t vfo;			/* vfo selection */
 port_t myport;
-#endif
 int ssb_bandwidth = 3000;
 int cw_bandwidth = 0;
 int serial_rate = 2400;
@@ -401,8 +387,6 @@ int zones[MAX_ZONES];		/* same for cq zones or itu zones;
 struct mults_t multis[MAX_MULTS]; /**< worked multis */
 int nr_multis = 0;		/**< number of multis in multis[] */
 
-GPtrArray *mults_possible;
-
 int multlist = 0;
 
 int callareas[20];
@@ -425,15 +409,15 @@ int ymax, xmax;			/* screen size */
 pid_t pid;
 struct tm *time_ptr, time_ptr_cabrillo;
 
-float freq;
-float mem;
+freq_t freq;
+freq_t mem;
 int logfrequency = 0;
 int rit;
 int trx_control = 0;
 int showfreq = 0;
-float bandfrequency[NBANDS] = {
-    1830.0, 3525.0, 7010.0, 10105.0, 14025.0, 18070.0, 21025.0, 24900.0,
-    28025.0, 0.
+freq_t bandfrequency[NBANDS] = {
+    1830000, 3525000, 7010000, 10105000, 14025000, 18070000, 21025000, 24900000,
+    28025000, 0.
 };
 
 char headerline[81] =
@@ -476,64 +460,64 @@ int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
 pthread_t background_thread;
 static struct termios oldt, newt;
 
-/** parse program options
- */
-void parse_options(int argc, char *argv[]) {
-    while ((argc > 1) && (argv[1][0] == '-')) {
-	switch (argv[1][1]) {
-	    /* verbose option */
-	    case 'f':
-		if (strlen(argv[1] + 2) > 0) {
-		    if ((*(argv[1] + 2) == '~') && (*(argv[1] + 3) == '/')) {
-			/* tilde expansion */
-			config_file = g_strconcat(g_get_home_dir(),
-						  argv[1] + 3, NULL);
-		    } else {
-			config_file = g_strdup(argv[1] + 2);
-		    }
-		}
-		break;
-	    case 's':
-		if (strlen(argv[1] + 2) > 0)
-		    strcpy(synclogfile, argv[1] + 2);
-		break;
-	    case 'd':		// debug rigctl
-		debugflag = 1;
-		break;
-	    case 'v':		// verbose startup
-		verbose = 1;
-		break;
-	    case 'V':		// output version
-		printf("Version: tlf-%s\n", VERSION);
-		exit(0);
-		break;
-	    case 'n':		// disable packet
-		nopacket = 1;
-		break;
-	    case 'r':
-		no_trx_control = 1; // disable radio control
-		break;
-	    case 'i':
-		convert_cabrillo = 1;
-		break;
-	    default:
-		printf("Use: tlf [-v] Verbose\n");
-		printf("         [-V] Version\n");
-		printf("         [-f] Configuration file\n");
-		printf("         [-d] Debug mode\n");
-		printf("         [-h] This message\n");
-		printf("         [-n] Start without cluster hookup\n");
-		printf("         [-r] Start without radio control\n");
-		printf("         [-i] Import cabrillo file to Tlf format\n");
-		exit(0);
-		break;
-	}
-	--argc;
-	++argv;
+/*-------------------------parse program options---------------------------*/
+const char *argp_program_version = "tlf-" VERSION;
+const char *argp_program_bug_address = "<tlf-devel@nongnu.org>";
+static const char program_description[] =
+    "tlf - contest logging program for amateur radio operators";
+static const struct argp_option options[] = {
+    {
+	"config",   'f', "FILE", 0,
+	"Use FILE as configuration file instead of logcfg.dat in the current directory"
+    },
+    {"import",      'i', 0, 0,  "Import cabrillo file to Tlf format"},
+    {"no-cluster",  'n', 0, 0,  "Start without cluster hookup" },
+    {"no-rig",      'r', 0, 0,  "Start without radio control" },
+    {"sync",        's', "URL", 0,  "Synchronize log with other node" },
+    {"debug",       'd', 0, 0,  "Debug mode" },
+    {"verbose",     'v', 0, 0,  "Produce verbose output" },
+    { 0 }
+};
+
+/* parse a single option */
+static error_t parse_opt(int key, char *arg, struct argp_state *state) {
+    switch (key) {
+	case 'f':		// config file
+	    config_file = g_strdup(arg);
+	    break;
+	case 'n':		// disable packet
+	    nopacket = 1;
+	    break;
+	case 'r':
+	    no_trx_control = 1; // disable radio control
+	    break;
+	case 'i':
+	    convert_cabrillo = 1;
+	    break;
+	case 's':
+	    if (strlen(arg) >= 120) {
+		printf("Argument too long for sync\n");
+		exit(EXIT_FAILURE);
+	    }
+	    strcpy(synclogfile, arg);
+	    break;
+	case 'd':		// debug rigctl
+	    debugflag = 1;
+	    break;
+	case 'v':		// verbose startup
+	    verbose = 1;
+	    break;
+
+	default:
+	    return ARGP_ERR_UNKNOWN;
     }
+    return 0;
 }
 
 
+const static struct argp argp = { options, parse_opt, NULL, program_description };
+
+
 /** initialize user interface */
 void ui_init() {
 
@@ -548,7 +532,8 @@ void ui_init() {
     char *term = getenv("TERM");
     if (strcasecmp(term, "rxvt") == 0) {
 	use_rxvt = 1;
-    } else if (strcasecmp(term, "xterm") == 0) {
+    } else if ((strcasecmp(term, "xterm") == 0) ||
+	       (strcasecmp(term, "xterm-256color") == 0)) {
 	use_xterm = 1;
 	use_rxvt = 1;
     }
@@ -585,7 +570,7 @@ void ui_init() {
 	char c;
 
 	showmsg("!! TLF needs at least 25 lines and 80 columns !!");
-	showmsg("   Continue anyway? Y/(N)");
+	showmsg("   Continue anyway? Y/(N) ");
 	c = toupper(key_get());
 	if (c != 'Y') {
 	    showmsg("73 es cuagn");
@@ -593,18 +578,17 @@ void ui_init() {
 	    endwin();
 	    exit(EXIT_FAILURE);
 	}
-	showmsg("");
+	clearmsg();
     }
 
     if (!has_colors() || (start_color() == ERR)) {
 	showmsg("Sorry, terminal does not support color");
 	showmsg("Try TERM=linux  or use a text console !!");
-	sleep(2);
+	sleep(1);
 	endwin();
 	exit(EXIT_FAILURE);
     }
 
-
     refreshp();
 
     noecho();
@@ -656,10 +640,10 @@ void ui_color_init() {
 int databases_load() {
     int status;
 
-    showmsg("reading country data");
+    showmsg("Reading country data");
     readctydata();		/* read ctydb.dat */
 
-    showmsg("reading configuration data");
+    showmsg("Reading configuration data");
     status = read_logcfg(); 	/* read the configuration file */
     status |= read_rules();	/* read the additional contest rules
 				   in "rules/contestname" */
@@ -673,27 +657,25 @@ int databases_load() {
 
     if (*call == '\0') {
 	showmsg
-	("WARNING: No callsign defined in logcfg.dat! exiting...\n\n\n");
+	    ("WARNING: No callsign defined in logcfg.dat! exiting...\n");
 	return EXIT_FAILURE;
     }
 
 
     if (multlist == 1) {
-	showmsg("reading multiplier data      ");
+	showmsg("Reading multiplier data      ");
 	if (strlen(multsfile) == 0) {
-	    mvprintw(9, 0, "No multiplier file specified, exiting.. !!\n");
-	    refreshp();
-	    sleep(5);
-	    exit(1);
+	    showmsg("No multiplier file specified, exiting.. !!");
+	    return EXIT_FAILURE;
 	}
     }
     init_and_load_multipliers();
 
-    showmsg("reading callmaster data");
+    showmsg("Reading callmaster data");
     load_callmaster();
 
     if (*exchange_list != '\0') {
-	showmsg("reading initial exchange file");
+	showmsg("Reading initial exchange file");
 	main_ie_list = make_ie_list(exchange_list);
 
 	if (main_ie_list == NULL) {
@@ -727,11 +709,8 @@ int databases_load() {
 
 void hamlib_init() {
 
-#ifdef HAVE_LIBHAMLIB		// Code for hamlib interface
     int status;
 
-    showmsg("HAMLIB compiled in");
-
     if (no_trx_control == 1) {
 	trx_control = 0;
     }
@@ -756,13 +735,6 @@ void hamlib_init() {
 	    sleep(1);
 	}
     }
-#else
-    showmsg("No Hamlib compiled in!");
-
-    trx_control = 0;
-    showmsg("Disabling rig control!");
-    sleep(1);
-#endif				/* HAVE_LIBHAMLIB */
 }
 
 void fldigi_init() {
@@ -830,7 +802,7 @@ void keyer_init() {
 
 	    write_tone();
 
-	    snprintf(keyerbuff, 3, "%2d", GetCWSpeed());
+	    snprintf(keyerbuff, 3, "%2u", GetCWSpeed());
 	    netkeyer(K_SPEED, keyerbuff);		// set speed
 
 	    netkeyer(K_WEIGHT, weightbuf);		// set weight
@@ -858,6 +830,44 @@ void keyer_init() {
 }
 
 
+void show_GPL() {
+    printw("\n\n\n");
+    printw("           TTTTT  L      FFFFF\n");
+    printw("             T    L      F    \n");
+    printw("             T    L      FFFFF\n");
+    printw("             T    L      F    \n");
+    printw("             T    LLLLL  F    \n");
+    printw
+	("\n\nThis program is copyright 2002, 2003, 2004 by Rein Couperus, PA0R\n\n");
+    printw
+	("It is free software; you can redistribute it and/or modify it under the terms\n");
+    printw
+	("of the GNU General Public License as published by the Free Software Foundation;\n");
+    printw
+	("either version 2 of the License, or (at your option) any later version.\n\n");
+    printw
+	("This program is distributed in the hope that it will be useful, but\n");
+    printw
+	("WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n");
+    printw
+	("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License\n");
+    printw
+	("for more details.\n");
+
+    refreshp();
+}
+
+
+int isFirstStart() {
+    FILE *fp;
+
+    if ((fp = fopen(".paras", "r")) == NULL) {
+	return 1;
+    }
+    fclose(fp);
+
+    return 0;
+}
 
 /** cleanup function
  *
@@ -877,14 +887,10 @@ void tlf_cleanup() {
     else
 	deinit_controller();
 
-#ifdef HAVE_LIBHAMLIB
-
     if (my_rig) {
 	close_tlf_rig(my_rig);
     }
 
-#endif
-
 #ifdef HAVE_LIBXMLRPC
     if (digikeyer == FLDIGI) {
 	fldigi_xmlrpc_cleanup();
@@ -903,9 +909,10 @@ void tlf_cleanup() {
 int main(int argc, char *argv[]) {
     int j;
     int ret;
-    char tlfversion[80] = "";
+    char welcome[80];
+    sprintf(welcome, "        Welcome to %s by PA0R!!", argp_program_version);
 
-    parse_options(argc, argv);
+    argp_parse(&argp, argc, argv, 0, 0, NULL);  // parse options
 
     ui_init();
 
@@ -925,9 +932,16 @@ int main(int argc, char *argv[]) {
     hiscall[0] = '\0';
 
 
-    sprintf(tlfversion,
-	    "        Welcome to tlf-%s by PA0R!!", VERSION);
-    showmsg(tlfversion);
+    if (isFirstStart()) {
+	/* first time called in this directory */
+	verbose = 1;
+	printw(welcome);
+	show_GPL();
+	sleep(5);
+	clear();
+    }
+
+    showmsg(welcome);
     showmsg("");
 
     total = 0;
@@ -964,27 +978,24 @@ int main(int argc, char *argv[]) {
     lan_init();
     keyer_init();
 
-    clear();
-    mvprintw(0, 0, "        Welcome to tlf-%s by PA0R!!\n\n", VERSION);
-    refreshp();
+    scroll_log();		/* read the last 5  log lines and set the qso number */
+    nr_qsos = readcalls();	/* read the logfile for score and dupe */
 
     checkparameters();		/* check .paras file */
     getmessages();		/* read .paras file */
 
+    clearmsg_wait();
+
     packet_init();
-    getwwv();			/* get the latest wwv info from packet */
-
-    scroll_log();		/* read the last 5  log lines and set the qso number */
-
-    nr_qsos = readcalls();	/* read the logfile for score and dupe */
 
     clear_display();		/* tidy up the display */
     attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-    for (j = 13; j <= 23; j++) {	/* wipe lower window */
+    for (j = 13; j <= LINES - 1; j++) {	/* wipe lower window */
 	mvprintw(j, 0, backgrnd_str);
     }
     refreshp();
 
+    getwwv();			/* get the latest wwv info from packet */
     bm_init();			/* initialize bandmap */
 
     atexit(tlf_cleanup); 	/* register cleanup function */
