@@ -23,10 +23,10 @@
 #include "getctydata.h"
 #include "getpx.h"
 #include "tlf.h"
+#include "bands.h"
 
 
-int pacc_pa(void)
-{
+int pacc_pa(void) {
 
     extern int w_cty;
     extern int ve_cty;
@@ -49,18 +49,19 @@ int pacc_pa(void)
 //extern int band_score[];
 
     int pxnr;
+    /* FIXME: Initialisation is wrong as 0 is bandindex for 160m */
     int i = 0, j = 0, k;
 
     k = 1;
 
     switch (bandinx) {
 
-    case BANDINDEX_160:
-    case BANDINDEX_80:
-    case BANDINDEX_40:
-    case BANDINDEX_20:
-    case BANDINDEX_15:
-    case BANDINDEX_10:
+	case BANDINDEX_160:
+	case BANDINDEX_80:
+	case BANDINDEX_40:
+	case BANDINDEX_20:
+	case BANDINDEX_15:
+	case BANDINDEX_10:
 	    i = inxes[bandinx];
 	    j = bandinx;
 	    break;
