@@ -1,7 +1,7 @@
 /*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0rct@amsat.org>
-* 		2011-2015           Thomas Beierlein <tb@forth-ev.de>
+* 		2011-2019           Thomas Beierlein <tb@forth-ev.de>
 * 		2013 		    Fred DH5FS
 *               2013-2016           Ervin Hegedus - HA2OS <airween@gmail.com>
 *
@@ -24,6 +24,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdbool.h>
 #include <unistd.h>
 
 #include "bandmap.h"
@@ -38,14 +39,10 @@
 #include "setcontest.h"
 #include "startmsg.h"
 #include "tlf_curses.h"
+#include "searchlog.h"
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
+#include <config.h>
+#include <hamlib/rig.h>
 
 
 extern int cwkeyer;
@@ -60,16 +57,11 @@ extern int packetinterface;
 extern int tncport;
 extern int shortqsonr;
 extern char *cabrillo;
-#ifdef HAVE_LIBHAMLIB
 extern rmode_t digi_mode;
-#endif
 
 int exist_in_country_list();
 int continent_found();
 
-char inputbuffer[160];
-FILE *fp;
-
 void KeywordRepeated(char *keyword);
 void KeywordNotSupported(char *keyword);
 void ParameterNeeded(char *keyword);
@@ -86,8 +78,9 @@ int read_logcfg(void) {
 
     char defltconf[80];
 
-    int status = PARSE_OK;
+    int status;
     int i;
+    FILE *fp;
 
     contest = 0;
     partials = 0;
@@ -105,7 +98,7 @@ int read_logcfg(void) {
 	if (digi_message[i] != NULL) {
 	    free(digi_message[i]);
 	    digi_message[i] = NULL;
-        }
+	}
     }
     if (cabrillo != NULL) {
 	free(cabrillo);
@@ -126,24 +119,38 @@ int read_logcfg(void) {
 	    endwin();
 	    exit(1);
 	} else {
-	    showstring("Using (Read Only) file", defltconf);
+	    showstring("Using default (Read Only) config file:", defltconf);
 	}
 
     } else
-	showstring("Opening config file", config_file);
+	showstring("Reading config file:", config_file);
 
-    while (fgets(inputbuffer, 120, fp) != NULL) {
+    status = parse_configfile(fp);
+    fclose(fp);
 
-	if ((inputbuffer[0] != '#') && (strlen(inputbuffer) > 1)) {
-	    /* skip comments and
-	     * empty lines */
-	    status |= parse_logcfg(inputbuffer);
+    return status;
+}
+
+static bool isCommentLine(char *buffer) {
+    if ((buffer[0] != '#') && (buffer[0] != ';') && (strlen(buffer) > 1)) {
+	return false;
+    } else {
+	return true;
+    }
+}
+
+int parse_configfile(FILE *fp) {
+    int status = PARSE_OK;
+    char buffer[160];
+
+    while (fgets(buffer, sizeof(buffer), fp) != NULL) {
+	/* skip comments and empty lines */
+	if (!isCommentLine(buffer)) {
+	    status |= parse_logcfg(buffer);
 	}
     }
 
-    fclose(fp);
-
-    return (status);
+    return status;
 }
 
 /** convert band string into index number (0..NBANDS-1) */
@@ -216,9 +223,7 @@ int parse_logcfg(char *inputbuffer) {
     extern int tnc_serial_rate;
     extern char lastwwv[];
     extern int serial_rate;
-#ifdef HAVE_LIBHAMLIB
     extern rig_model_t myrig_model;
-#endif
     extern char *rigportname;
     extern int rignumber;
     extern char rigconf[];
@@ -291,7 +296,6 @@ int parse_logcfg(char *inputbuffer) {
     /* end LZ3NY mods */
     extern int tlfcolors[8][2];
     extern char synclogfile[];
-    extern int scale_values[];
     extern char sc_device[40];
     extern char controllerport[80];	// port for multi-mode controller
     extern char clusterlogin[];
@@ -315,6 +319,8 @@ int parse_logcfg(char *inputbuffer) {
     extern unsigned char rigptt;
     extern int minitest;
     extern int unique_call_multi;
+    extern int lan_port;
+    extern int verbose;
 
     char *commands[] = {
 	"enable",		/* 0 */		/* deprecated */
@@ -456,7 +462,7 @@ int parse_logcfg(char *inputbuffer) {
 	"CWPOINTS",		/* 135 */
 	"SOUNDCARD",
 	"SIDETONE_VOLUME",
-	"S_METER",
+	"S_METER",				/* deprecated */
 	"SC_DEVICE",
 	"MFJ1278_KEYER",	/* 140 */
 	"CLUSTERLOGIN",
@@ -578,9 +584,11 @@ int parse_logcfg(char *inputbuffer) {
 	"ALT_DK5",
 	"ALT_DK6",
 	"ALT_DK7",
-	"ALT_DK8",
+	"ALT_DK8",			/* 260 */
 	"ALT_DK9",
-	"ALT_DK10"
+	"ALT_DK10",
+	"CALLMASTER",
+	"LAN_PORT"                     /* 264 */
     };
 
     char **fields;
@@ -1014,9 +1022,8 @@ int parse_logcfg(char *inputbuffer) {
 		rignumber = 2000;
 	    else
 		rignumber = atoi(buff);
-#ifdef HAVE_LIBHAMLIB
+
 	    myrig_model = (rig_model_t) rignumber;
-#endif
 
 	    break;
 	}
@@ -1175,8 +1182,8 @@ int parse_logcfg(char *inputbuffer) {
 
 	    int counter = 0;
 	    static char country_list_raw[50] = ""; 	/* use only first
-						       COUNTRY_LIST
-						       definition */
+						   	COUNTRY_LIST
+						   	definition */
 	    char temp_buffer[255] = "";
 	    char buffer[255] = "";
 	    FILE *fp;
@@ -1291,10 +1298,13 @@ int parse_logcfg(char *inputbuffer) {
 	case 103 ... 116: {	// get phone messages
 	    PARAMETER_NEEDED(teststring);
 	    g_strlcpy(ph_message[ii - 103], g_strchomp(fields[1]), 71);
-	    mvprintw(15, 5, "A: Phone message #%d is %s", ii - 103,
+	    if (verbose) {
+		gchar *tmp;
+		tmp = g_strdup_printf("  Phone message #%d is %s", ii - 103,
 		     ph_message[ii - 103]);	// (W9WI)
-	    refreshp();
-	    //                             system ("sleep 2");
+		showmsg(tmp);
+		g_free(tmp);
+	    }
 	    break;
 	}
 	case 117: {		// WAZ Zone is a Multiplier
@@ -1403,24 +1413,7 @@ int parse_logcfg(char *inputbuffer) {
 		strcpy(sc_volume, "70");
 	    break;
 	}
-	case 138: {
-	    int i = 0;
-
-	    PARAMETER_NEEDED(teststring);
-	    tk_ptr = strtok(fields[1], ":,.-_\t ");
-
-	    if (tk_ptr != NULL) {
-		while (tk_ptr) {
-		    if (i < 20)
-			scale_values[i] = atoi(tk_ptr);
-		    tk_ptr = strtok(NULL, ":,.-_\t ");
-		    i++;
-		}
-	    }
-
-	    break;
-	}
-	case 139: {		// dsp for s-meter
+	case 139: {
 	    PARAMETER_NEEDED(teststring);
 	    g_strlcpy(sc_device, g_strchomp(fields[1]), sizeof(sc_device));
 	    break;
@@ -1517,7 +1510,7 @@ int parse_logcfg(char *inputbuffer) {
 	    PARAMETER_NEEDED(teststring);
 	    strcpy(myqra, fields[1]);
 
-	    if (check_qra(myqra) > 0) {
+	    if (check_qra(myqra) == 0) {
 		showmsg
 		("WARNING: Invalid MYQRA parameters! exiting...");
 		sleep(5);
@@ -1575,8 +1568,8 @@ int parse_logcfg(char *inputbuffer) {
 
 	    int counter = 0;
 	    static char cont_multiplier_list[50] = ""; 	/* use only first
-						       CONTINENT_LIST
-						       definition */
+						   	CONTINENT_LIST
+						   	definition */
 	    char temp_buffer[255] = "";
 	    char buffer[255] = "";
 	    FILE *fp;
@@ -1750,17 +1743,25 @@ int parse_logcfg(char *inputbuffer) {
 	case 194 ... 207: {	// get QTC recv phone messages
 	    PARAMETER_NEEDED(teststring);
 	    g_strlcpy(qtc_phrecv_message[ii - 194], g_strchomp(fields[1]), 71);
-	    mvprintw(15, 5, "A: QTC RECV phone message #%d is %s", ii - 194,
-		     qtc_phrecv_message[ii - 194]);
-	    refreshp();
+	    if (verbose) {
+		gchar *tmp;
+		tmp = g_strdup_printf("  QTC RECV phone message #%d is %s",
+		    ii - 194, qtc_phrecv_message[ii - 194]);
+		showmsg(tmp);
+		g_free(tmp);
+	    }
 	    break;
 	}
 	case 208 ... 221: {	// get QTC send phone messages
 	    PARAMETER_NEEDED(teststring);
 	    g_strlcpy(qtc_phsend_message[ii - 208], g_strchomp(fields[1]), 71);
-	    mvprintw(15, 5, "A: QTC SEND phone message #%d is %s", ii - 208,
-		     qtc_phrecv_message[ii - 208]);
-	    refreshp();
+	    if (verbose) {
+		gchar *tmp;
+		tmp = g_strdup_printf("  QTC SEND phone message #%d is %s",
+		    ii - 208, qtc_phrecv_message[ii - 208]);
+		showmsg(tmp);
+		g_free(tmp);
+	    }
 	    break;
 	}
 	case 222: {
@@ -1911,7 +1912,6 @@ int parse_logcfg(char *inputbuffer) {
 	    break;
 	}
 	case 237: {
-#ifdef HAVE_LIBHAMLIB
 	    PARAMETER_NEEDED(teststring);
 	    g_strchomp(fields[1]);
 	    if (strcmp(fields[1], "USB") == 0)
@@ -1928,7 +1928,6 @@ int parse_logcfg(char *inputbuffer) {
 		sleep(5);
 		exit(1);
 	    }
-#endif
 	    break;
 	}
 	case 238 ... 249: {
@@ -1988,7 +1987,7 @@ int parse_logcfg(char *inputbuffer) {
 		    *nl = ' ';
 	    }
 	    break;
-	case 253 ... 263: {
+	case 253 ... 262: {
 	    PARAMETER_NEEDED(teststring);
 	    if (digi_message[ii - 239]) {
 		KeywordRepeated(commands[ii]);
@@ -2003,6 +2002,21 @@ int parse_logcfg(char *inputbuffer) {
 	    }
 	    break;
 	}
+	case 263: {
+	    PARAMETER_NEEDED(teststring);
+	    g_strchomp(fields[1]);
+	    if (callmaster_filename != NULL) {
+		g_free(callmaster_filename);
+	    }
+	    callmaster_filename = g_strdup(fields[1]);
+
+	    break;
+	}
+	case 264: {
+	    PARAMETER_NEEDED(teststring);
+	    lan_port = atoi(fields[1]);
+	    break;
+	}
 	default: {
 	    KeywordNotSupported(g_strstrip(inputbuffer));
 	    break;
