@@ -24,6 +24,6 @@
 
 int qrb(double lon1, double lat1, double lon2, double lat2,
 	double *distance, double *azimuth);
-int qrb_(double *range, double *bearing);
+int get_qrb(double *range, double *bearing);
 
 #endif /* end of include guard: QRB_H */
