@@ -59,9 +59,9 @@ int readcalls(void) {
     char zonebuf[3];
     char checkcall[20];
     int i = 0, l = 0, n = 0, r = 0, s = 0;
-    unsigned int k = 0;
+    unsigned int k;
     int m = 0;
-    int t = 0, tt = 0;
+    int t;
     int z = 0;
     int add_ok;
     char multbuffer[40];
@@ -79,8 +79,7 @@ int readcalls(void) {
 
     FILE *fp;
 
-    clear();
-    mvprintw(4, 0, "Reading logfile...\n");
+    showmsg("Reading logfile... ");
     refreshp();
 
     /* reset counter and score anew */
@@ -127,17 +126,15 @@ int readcalls(void) {
     }
 
     if ((fp = fopen(logfile, "r")) == NULL) {
-	mvprintw(5, 0, "Error opening logfile.\n");
+	showmsg("Error opening logfile ");
 	refreshp();
 	sleep(2);
 	exit(1);
     }
     i = 0;
-    k = 0;
     l = 0;
 
     s = 0;
-    t = 0;
 
     while (fgets(inputbuffer, 90, fp) != NULL) {
 	pfxnumcntidx = -1;
@@ -250,16 +247,16 @@ int readcalls(void) {
 
 		} else if (serial_section_mult == 1) {
 
-		    tt = 0;
-
 		    memset(multbuffer, 0, 39);
 
-		    for (t = 54; t < 64; t++) {
-			if (inputbuffer[t] >= 'A' && inputbuffer[t] <= 'Z') {
-			    multbuffer[tt] = inputbuffer[t];
-			    tt++;
-			}
-		    }
+		    strncpy(multbuffer, inputbuffer + 68, 3);
+		    g_strchomp(multbuffer);
+
+		} else if (sectn_mult == 1) {
+		    memset(multbuffer, 0, 39);
+
+		    strncpy(multbuffer, inputbuffer + 68, 3);
+		    g_strchomp(multbuffer);
 
 		} else if (serial_grid4_mult == 1) {
 
@@ -332,7 +329,7 @@ int readcalls(void) {
 	} else if (strncmp("DIG", inputbuffer + 3, 3) == 0) {
 	    qsomode = DIGIMODE;
 	} else {
-	    mvprintw(5, 0, "Invalid line format in line %d.\n", linenr);
+	    shownr("Invalid line format in line %d.\n", linenr);
 	    refreshp();
 	    sleep(2);
 	    exit(1);
