@@ -2,7 +2,7 @@
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2003	  LZ3NY <lz3ny@bfra.org>
 * 		2003-2004 Rein Couperus <pa0rct@amsat.org>
-* 		2011-2015           Thomas Beierlein <tb@forth-ev.de>
+* 		2011-2019 Thomas Beierlein <tb@forth-ev.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -43,29 +43,27 @@ extern char logfile[];
 
 int read_rules() {
 
-    char mit_contest_rule[80];
     char contest_conf[80] = "";	/* contest_conf needs room
 				   for contest name... (PA0R) */
     char basic_contest_conf[75] = PACKAGE_DATA_DIR;
-    FILE *mit_contest_file;
+    FILE *fp;
 
     int status = PARSE_OK;
 
     /* If no contest is given, whichcontest is set to default "qso"
        (PA0R, Sep 24 2003)*/
     if (strlen(whichcontest) == 0) {
-	showmsg("contest name is empty! Assuming general qso mode!! ");
+	showmsg("Contest name is empty! Assuming general qso mode!! ");
 	strcpy(whichcontest, "qso");
 	return (PARSE_ERROR);
     }
 
     if (strlen(whichcontest) >= 40) {
-	showmsg("contest name is too long!");
-	showmsg("exiting...");
+	showmsg("Contest name is too long!");
+	showmsg("Exiting...");
 	exit(1);
     }
 
-    memset(mit_contest_rule, '\0', strlen(whichcontest) + 6);
     strcat(contest_conf, "rules/");
     strcat(contest_conf, whichcontest);
     /* If rules are not found in local working directory,
@@ -73,44 +71,27 @@ int read_rules() {
     strcat(basic_contest_conf, "/rules/");
     strcat(basic_contest_conf, whichcontest);
 
-    if ((mit_contest_file = fopen(contest_conf, "r")) != NULL) {
+    if ((fp = fopen(contest_conf, "r")) != NULL) {
 
-	showstring("reading contest rules file:", contest_conf);
+	showstring("Reading contest rules file:", contest_conf);
 
-	while (fgets(mit_contest_rule, sizeof(mit_contest_rule),
-		     mit_contest_file) != NULL) {
-
-	    /* if not comment interpret line */
-	    if ((mit_contest_rule[0] != '#') && (mit_contest_rule[0] != ';')) {
-		status |= parse_logcfg(mit_contest_rule);
-	    }
-	}
-	fclose(mit_contest_file);
-	showstring("Using contest rules file: ", contest_conf);
-    } else if ((mit_contest_file = fopen(basic_contest_conf, "r")) != NULL) {
-
-	showstring("reading contest rules file:", basic_contest_conf);
-
-	while (fgets(mit_contest_rule, sizeof(mit_contest_rule),
-		     mit_contest_file) != NULL) {
-
-	    /* if not comment interpret line */
-	    if ((mit_contest_rule[0] != '#') && (mit_contest_rule[0] != ';')) {
-		status |= parse_logcfg(mit_contest_rule);
-	    }
-	}
-	fclose(mit_contest_file);
-	showstring("Using contest rules file:", basic_contest_conf);
+	status = parse_configfile(fp);
+	fclose(fp);
     }
+    else if ((fp = fopen(basic_contest_conf, "r")) != NULL) {
 
+	showstring("Reading contest rules file:", basic_contest_conf);
+
+	status = parse_configfile(fp);
+	fclose(fp);
+    }
     else {
-	showstring("There is no contest rules file", contest_conf);
+	showstring("There is no contest rules file:", contest_conf);
 	showmsg("Assuming regular QSO operation. Logfile is qso.log");
 	strcpy(whichcontest, "qso");	/* default use general qso mode...
 					   (PA0R, 24 Sept. 2003) */
 	setcontest();
 	strcpy(logfile, "qso.log");
-	refreshp();
     }
 
     /*
@@ -125,8 +106,7 @@ int read_rules() {
 		showmsg("Out of memory: unable to create digi message!");
 		sleep(2);
 		exit(EXIT_FAILURE);
-	    }
-	    else {
+	    } else {
 		char *c = strrchr(digi_message[i], '\n');
 		if (c)
 		    *c = ' ';
@@ -134,5 +114,5 @@ int read_rules() {
 	}
     }
 
-    return (status);
+    return status;
 }
