@@ -22,7 +22,9 @@
 #ifndef SENDBUF_H
 #define SENDBUF_H
 
-char short_number( char c);
+char short_number(char c);
 void sendmessage(const char *msg);
+void send_standard_message(int msg);
+void send_keyer_message(int msg);
 
 #endif /*  SENDBUF_H */
