@@ -30,12 +30,10 @@
 #include "globalvars.h"
 
 
-void send_bandswitch(int trxqrg);
+void send_bandswitch(freq_t trxqrg);
 
-#ifdef HAVE_LIBHAMLIB		//code for Hamlib interface
 static int parse_rigconf();
 static void debug_tlf_rig();
-#endif
 
 /* check if call input field contains a frequency value and switch to it.
  *
@@ -45,28 +43,26 @@ int sendqrg(void) {
     extern char hiscall[];
     extern int trx_control;
 
-    float trxqrg;
 
     if (!trx_control) {
 	return 0;               /* nothing to do here */
     }
 
-    trxqrg = atof(hiscall);
+    const freq_t trxqrg = atof(hiscall) * 1000.0;
 
-    int bandinx = freq2band((unsigned int)(trxqrg * 1000.0));
+    int bandinx = freq2band(trxqrg);
 
     if (bandinx == BANDINDEX_OOB) {
 	return 0;   // not a frequency or out of band
     }
 
-    set_outfreq(trxqrg * 1000);
-    send_bandswitch((int) trxqrg);
+    set_outfreq(trxqrg);
+    send_bandswitch(trxqrg);
 
-    return (int) trxqrg;
+    return trxqrg;
 }
 
 /**************************************************************************/
-#ifdef HAVE_LIBHAMLIB		//code for Hamlib interface
 
 int init_tlf_rig(void) {
     extern RIG *my_rig;
@@ -129,7 +125,7 @@ int init_tlf_rig(void) {
 
     // parse RIGCONF parameters
     if (parse_rigconf() < 0) {
-        return -1;
+	return -1;
     }
 
     retcode = rig_open(my_rig);
@@ -151,7 +147,7 @@ int init_tlf_rig(void) {
 	    return -1;
     }
 
-    shownr("freq =", (int) rigfreq);
+    shownr("Freq =", (int) rigfreq);
 
     if (debugflag) {	// debug rig control
 	debug_tlf_rig();
@@ -169,7 +165,6 @@ int init_tlf_rig(void) {
 	    break;
     }
 
-    sleep(1);
     return 0;
 }
 
@@ -225,6 +220,7 @@ static int parse_rigconf() {
     return 0;
 }
 
+
 static void debug_tlf_rig() {
     extern RIG *my_rig;
     freq_t rigfreq;
@@ -267,5 +263,3 @@ static void debug_tlf_rig() {
     sleep(10);
 
 }
-
-#endif				// end code for Hamlib interface
