@@ -23,12 +23,16 @@
 #include <pthread.h>
 #include <unistd.h>
 
+#include "clear_display.h"
+#include "clusterinfo.h"
 #include "stoptx.h"
 #include "tlf_panel.h"
 #include "startmsg.h"
+#include "splitscreen.h"
 
 
 extern int use_rxvt;
+extern int ymax, xmax;
 
 int key_kNXT3 = 0;
 int key_kPRV3 = 0;
@@ -39,7 +43,7 @@ pthread_mutex_t panel_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static int getkey(int wait);
 static int onechar(void);
-
+void resize_layout(void);
 
 /** fake refresh code to use update logic for panels */
 void refreshp() {
@@ -141,6 +145,10 @@ static int getkey(int wait) {
 
     x = onechar();
 
+    if (x == KEY_RESIZE) {
+	resize_layout();
+    }
+
     nodelay(stdscr, FALSE);
 
     return x;
@@ -318,3 +326,15 @@ static int onechar(void) {
 
     return x;
 }
+
+
+/* Handles resizing of windows
+ * As ncurses handles most of it itself, it just redraws the main
+ * display and resizes only the packet panel windows
+ */
+void resize_layout(void) {
+    getmaxyx(stdscr, ymax, xmax);
+    clear_display();
+    clusterinfo();
+    refresh_splitlayout();
+}
