@@ -21,6 +21,8 @@
 #ifndef WRITE_KEYER_H
 #define WRITE_KEYER_H
 
+void keyer_append(const char *string);
+void keyer_flush();
 int write_keyer(void);
 
 #endif /* WRITE_KEYER_H */
