@@ -1,4 +1,4 @@
-// generated on Sat Nov 10 11:41:09 2018
+// generated on Tue Nov 12 19:44:59 2019
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
@@ -14,7 +14,14 @@ void test_load_multi_dos(void **state);
 void test_load_multi_file_not_found(void **state);
 void test_load_multi_leading_space(void **state);
 void test_load_multi_no_file(void **state);
+void test_load_multi_redefined(void **state);
 void test_load_multi_sorted(void **state);
+void test_load_multi_with_alias(void **state);
+void test_load_multi_with_emptyalias(void **state);
+void test_match_length_match_alias(void **state);
+void test_match_length_match_alias2(void **state);
+void test_match_length_match_mult(void **state);
+void test_match_length_no_match(void **state);
 void test_remember_mult_empty(void **state);
 void test_remember_mult_one(void **state);
 void test_remember_mult_same_2x(void **state);
@@ -38,13 +45,20 @@ int main(void) {
       cmocka_unit_test_setup_teardown(test_remember_mult_two, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_remember_mult_same_2x, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_remember_mult_same_2x_newband, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_write_mult, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi_no_file, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi_file_not_found, setup_default, NULL),
-      cmocka_unit_test_setup_teardown(test_write_mult, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi_dos, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi_leading_space, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_load_multi_sorted, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_load_multi_redefined, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_load_multi_with_emptyalias, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_load_multi_with_alias, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_match_length_no_match, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_match_length_match_mult, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_match_length_match_alias, setup_default, NULL),
+      cmocka_unit_test_setup_teardown(test_match_length_match_alias2, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_wysiwyg_once, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_wysiwyg_multi, setup_default, NULL),
       cmocka_unit_test_setup_teardown(test_wysiwyg_multi_empty, setup_default, NULL),
