@@ -1,4 +1,4 @@
-// generated on Sat Nov 10 11:41:09 2018
+// generated on Tue Nov 12 19:44:59 2019
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
@@ -6,6 +6,8 @@
 
 int setup(void **state);
 void test_cabToTlf_ParseQSO(void **state);
+void test_cabToTlf_ParseQTC(void **state);
+void test_cabToTlf_ParseXQSO(void **state);
 void test_freeCabfmt(void **state);
 void test_parseLine(void **state);
 void test_readCabrilloFileNotFound(void **state);
@@ -28,6 +30,8 @@ int main(void) {
       cmocka_unit_test_setup_teardown(test_readCabrilloFileNotFound, NULL, NULL),
       cmocka_unit_test_setup_teardown(test_readCabrilloFormatNotFound, NULL, NULL),
       cmocka_unit_test_setup_teardown(test_cabToTlf_ParseQSO, NULL, NULL),
+      cmocka_unit_test_setup_teardown(test_cabToTlf_ParseXQSO, NULL, NULL),
+      cmocka_unit_test_setup_teardown(test_cabToTlf_ParseQTC, NULL, NULL),
     };
 
     return cmocka_run_group_tests(tests, setup, NULL);
