@@ -1,4 +1,4 @@
-// generated on Sat Nov 10 11:41:09 2018
+// generated on Tue Nov 12 19:44:59 2019
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
@@ -7,10 +7,12 @@
 void test_qra_ok4(void **state);
 void test_qra_ok6(void **state);
 void test_qra_short(void **state);
+void test_qra_wrong(void **state);
 
 int main(void) {
     const struct CMUnitTest tests[] = {
       cmocka_unit_test_setup_teardown(test_qra_short, NULL, NULL),
+      cmocka_unit_test_setup_teardown(test_qra_wrong, NULL, NULL),
       cmocka_unit_test_setup_teardown(test_qra_ok4, NULL, NULL),
       cmocka_unit_test_setup_teardown(test_qra_ok6, NULL, NULL),
     };
